Class: PAYJPv2::BalanceResponse
- Inherits:
-
Object
- Object
- PAYJPv2::BalanceResponse
- Defined in:
- lib/payjpv2/models/balance_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bank_info ⇒ Object
Returns the value of attribute bank_info.
-
#closed ⇒ Object
この Balance の清算が終了していれば true state=transfer であれば加盟店口座への入金作業完了、state=claim であれば PAY.JP で請求額の振込が確認できたことを表します。.
-
#closed_date ⇒ Object
Returns the value of attribute closed_date.
-
#created_at ⇒ Object
作成日時 (UTC, ISO 8601 形式).
-
#due_date ⇒ Object
Returns the value of attribute due_date.
-
#id ⇒ Object
残高 ID.
-
#livemode ⇒ Object
本番環境かどうか.
-
#net ⇒ Object
関連付けられている Statement の総額.
-
#object ⇒ Object
Returns the value of attribute object.
-
#state ⇒ Object
Balance の状態 | 値 | |:—| | collecting: 集計中 | | transfer: 入金 | | claim: 請求 |.
-
#statements ⇒ Object
関連付けられている Statement オブジェクトのリスト.
-
#updated_at ⇒ Object
更新時の日時 (UTC, ISO 8601 形式).
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BalanceResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BalanceResponse
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/payjpv2/models/balance_response.rb', line 129 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::BalanceResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::BalanceResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:object) self.object = attributes[:object] else self.object = 'balance' end if attributes.key?(:id) self.id = attributes[:id] else self.id = nil end if attributes.key?(:livemode) self.livemode = attributes[:livemode] else self.livemode = nil end if attributes.key?(:state) self.state = attributes[:state] else self.state = nil end if attributes.key?(:statements) if (value = attributes[:statements]).is_a?(Array) self.statements = value end else self.statements = nil end if attributes.key?(:closed) self.closed = attributes[:closed] else self.closed = nil end if attributes.key?(:closed_date) self.closed_date = attributes[:closed_date] else self.closed_date = nil end if attributes.key?(:due_date) self.due_date = attributes[:due_date] else self.due_date = nil end if attributes.key?(:net) self.net = attributes[:net] else self.net = nil end if attributes.key?(:bank_info) self.bank_info = attributes[:bank_info] else self.bank_info = nil end if attributes.key?(:created_at) self.created_at = attributes[:created_at] else self.created_at = nil end if attributes.key?(:updated_at) self.updated_at = attributes[:updated_at] else self.updated_at = nil end end |
Instance Attribute Details
#bank_info ⇒ Object
Returns the value of attribute bank_info.
42 43 44 |
# File 'lib/payjpv2/models/balance_response.rb', line 42 def bank_info @bank_info end |
#closed ⇒ Object
この Balance の清算が終了していれば true state=transfer であれば加盟店口座への入金作業完了、state=claim であれば PAY.JP で請求額の振込が確認できたことを表します。
33 34 35 |
# File 'lib/payjpv2/models/balance_response.rb', line 33 def closed @closed end |
#closed_date ⇒ Object
Returns the value of attribute closed_date.
35 36 37 |
# File 'lib/payjpv2/models/balance_response.rb', line 35 def closed_date @closed_date end |
#created_at ⇒ Object
作成日時 (UTC, ISO 8601 形式)
45 46 47 |
# File 'lib/payjpv2/models/balance_response.rb', line 45 def created_at @created_at end |
#due_date ⇒ Object
Returns the value of attribute due_date.
37 38 39 |
# File 'lib/payjpv2/models/balance_response.rb', line 37 def due_date @due_date end |
#id ⇒ Object
残高 ID
21 22 23 |
# File 'lib/payjpv2/models/balance_response.rb', line 21 def id @id end |
#livemode ⇒ Object
本番環境かどうか
24 25 26 |
# File 'lib/payjpv2/models/balance_response.rb', line 24 def livemode @livemode end |
#net ⇒ Object
関連付けられている Statement の総額
40 41 42 |
# File 'lib/payjpv2/models/balance_response.rb', line 40 def net @net end |
#object ⇒ Object
Returns the value of attribute object.
18 19 20 |
# File 'lib/payjpv2/models/balance_response.rb', line 18 def object @object end |
#state ⇒ Object
Balance の状態 | 値 | |:—| | collecting: 集計中 | | transfer: 入金 | | claim: 請求 |
27 28 29 |
# File 'lib/payjpv2/models/balance_response.rb', line 27 def state @state end |
#statements ⇒ Object
関連付けられている Statement オブジェクトのリスト
30 31 32 |
# File 'lib/payjpv2/models/balance_response.rb', line 30 def statements @statements end |
#updated_at ⇒ Object
更新時の日時 (UTC, ISO 8601 形式)
48 49 50 |
# File 'lib/payjpv2/models/balance_response.rb', line 48 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/payjpv2/models/balance_response.rb', line 366 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PAYJPv2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
91 92 93 |
# File 'lib/payjpv2/models/balance_response.rb', line 91 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/payjpv2/models/balance_response.rb', line 96 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/payjpv2/models/balance_response.rb', line 73 def self.attribute_map { :object => :object, :id => :id, :livemode => :livemode, :state => :state, :statements => :statements, :closed => :closed, :closed_date => :closed_date, :due_date => :due_date, :net => :net, :bank_info => :bank_info, :created_at => :created_at, :updated_at => :updated_at } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/payjpv2/models/balance_response.rb', line 342 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
119 120 121 122 123 124 125 |
# File 'lib/payjpv2/models/balance_response.rb', line 119 def self.openapi_nullable Set.new([ :closed_date, :due_date, :bank_info, ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/payjpv2/models/balance_response.rb', line 101 def self.openapi_types { :object => :'String', :id => :'String', :livemode => :'Boolean', :state => :'BalanceState', :statements => :'Array<StatementResponse>', :closed => :'Boolean', :closed_date => :'Time', :due_date => :'Time', :net => :'Integer', :bank_info => :'BankInfoResponse', :created_at => :'Time', :updated_at => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/payjpv2/models/balance_response.rb', line 310 def ==(o) return true if self.equal?(o) self.class == o.class && object == o.object && id == o.id && livemode == o.livemode && state == o.state && statements == o.statements && closed == o.closed && closed_date == o.closed_date && due_date == o.due_date && net == o.net && bank_info == o.bank_info && created_at == o.created_at && updated_at == o.updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'lib/payjpv2/models/balance_response.rb', line 437 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
329 330 331 |
# File 'lib/payjpv2/models/balance_response.rb', line 329 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
335 336 337 |
# File 'lib/payjpv2/models/balance_response.rb', line 335 def hash [object, id, livemode, state, statements, closed, closed_date, due_date, net, bank_info, created_at, updated_at].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
413 414 415 |
# File 'lib/payjpv2/models/balance_response.rb', line 413 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/payjpv2/models/balance_response.rb', line 419 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
407 408 409 |
# File 'lib/payjpv2/models/balance_response.rb', line 407 def to_s to_hash.to_s end |