Class: PAYJPv2::CheckoutSessionLineItemDataResponse
- Inherits:
-
Object
- Object
- PAYJPv2::CheckoutSessionLineItemDataResponse
- Defined in:
- lib/payjpv2/models/checkout_session_line_item_data_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount_subtotal ⇒ Object
割引や税金が適用される前のすべての商品の合計金額.
-
#amount_tax ⇒ Object
税額.
-
#amount_total ⇒ Object
割引と税金が適用された後のすべての商品の合計金額.
-
#currency ⇒ Object
価格の通貨。現在は ‘jpy` のみサポートしています。.
-
#description ⇒ Object
Returns the value of attribute description.
-
#id ⇒ Object
ID.
-
#object ⇒ Object
Returns the value of attribute object.
-
#price ⇒ Object
料金情報.
-
#quantity ⇒ Object
数量.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CheckoutSessionLineItemDataResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CheckoutSessionLineItemDataResponse
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::CheckoutSessionLineItemDataResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::CheckoutSessionLineItemDataResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:object) self.object = attributes[:object] else self.object = 'line_item' end if attributes.key?(:id) self.id = attributes[:id] else self.id = nil end if attributes.key?(:amount_subtotal) self.amount_subtotal = attributes[:amount_subtotal] else self.amount_subtotal = nil end if attributes.key?(:amount_tax) self.amount_tax = attributes[:amount_tax] else self.amount_tax = nil end if attributes.key?(:amount_total) self.amount_total = attributes[:amount_total] else self.amount_total = nil end if attributes.key?(:currency) self.currency = attributes[:currency] else self.currency = nil end if attributes.key?(:description) self.description = attributes[:description] else self.description = nil end if attributes.key?(:price) self.price = attributes[:price] else self.price = nil end if attributes.key?(:quantity) self.quantity = attributes[:quantity] else self.quantity = nil end end |
Instance Attribute Details
#amount_subtotal ⇒ Object
割引や税金が適用される前のすべての商品の合計金額
24 25 26 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 24 def amount_subtotal @amount_subtotal end |
#amount_tax ⇒ Object
税額
27 28 29 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 27 def amount_tax @amount_tax end |
#amount_total ⇒ Object
割引と税金が適用された後のすべての商品の合計金額
30 31 32 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 30 def amount_total @amount_total end |
#currency ⇒ Object
価格の通貨。現在は ‘jpy` のみサポートしています。
33 34 35 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 33 def currency @currency end |
#description ⇒ Object
Returns the value of attribute description.
35 36 37 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 35 def description @description end |
#id ⇒ Object
ID
21 22 23 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 21 def id @id end |
#object ⇒ Object
Returns the value of attribute object.
18 19 20 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 18 def object @object end |
#price ⇒ Object
料金情報
38 39 40 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 38 def price @price end |
#quantity ⇒ Object
数量
41 42 43 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 41 def quantity @quantity end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 318 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PAYJPv2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
81 82 83 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 81 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 86 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 66 def self.attribute_map { :object => :object, :id => :id, :amount_subtotal => :amount_subtotal, :amount_tax => :amount_tax, :amount_total => :amount_total, :currency => :currency, :description => :description, :price => :price, :quantity => :quantity } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 294 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 110 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 106 def self.openapi_nullable Set.new([ :description, ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 91 def self.openapi_types { :object => :'String', :id => :'String', :amount_subtotal => :'Integer', :amount_tax => :'Integer', :amount_total => :'Integer', :currency => :'Currency', :description => :'String', :price => :'PriceDetailsResponse', :quantity => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 265 def ==(o) return true if self.equal?(o) self.class == o.class && object == o.object && id == o.id && amount_subtotal == o.amount_subtotal && amount_tax == o.amount_tax && amount_total == o.amount_total && currency == o.currency && description == o.description && price == o.price && quantity == o.quantity end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 389 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
281 282 283 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 281 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
287 288 289 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 287 def hash [object, id, amount_subtotal, amount_tax, amount_total, currency, description, price, quantity].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
365 366 367 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 365 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 371 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
359 360 361 |
# File 'lib/payjpv2/models/checkout_session_line_item_data_response.rb', line 359 def to_s to_hash.to_s end |