Class: PAYJPv2::EventResponse
- Inherits:
-
Object
- Object
- PAYJPv2::EventResponse
- Defined in:
- lib/payjpv2/models/event_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
作成日時 (UTC, ISO 8601 形式).
-
#data ⇒ Object
このイベントに関連したリソースオブジェクト.
-
#id ⇒ Object
イベント ID.
-
#livemode ⇒ Object
本番環境かどうか.
-
#object ⇒ Object
Returns the value of attribute object.
-
#pending_webhooks ⇒ Object
設定された URL への通知が完了していない (2xx のレスポンスが得られていない) webhook の数.
-
#type ⇒ Object
イベントの種類.
-
#updated_at ⇒ Object
更新日時 (UTC, ISO 8601 形式).
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EventResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EventResponse
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/payjpv2/models/event_response.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::EventResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::EventResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:object) self.object = attributes[:object] else self.object = 'event' end if attributes.key?(:id) self.id = attributes[:id] else self.id = nil end if attributes.key?(:livemode) self.livemode = attributes[:livemode] else self.livemode = nil end if attributes.key?(:type) self.type = attributes[:type] else self.type = nil end if attributes.key?(:pending_webhooks) self.pending_webhooks = attributes[:pending_webhooks] else self.pending_webhooks = nil end if attributes.key?(:data) if (value = attributes[:data]).is_a?(Hash) self.data = value end else self.data = nil end if attributes.key?(:created_at) self.created_at = attributes[:created_at] else self.created_at = nil end if attributes.key?(:updated_at) self.updated_at = attributes[:updated_at] else self.updated_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
作成日時 (UTC, ISO 8601 形式)
36 37 38 |
# File 'lib/payjpv2/models/event_response.rb', line 36 def created_at @created_at end |
#data ⇒ Object
このイベントに関連したリソースオブジェクト
33 34 35 |
# File 'lib/payjpv2/models/event_response.rb', line 33 def data @data end |
#id ⇒ Object
イベント ID
21 22 23 |
# File 'lib/payjpv2/models/event_response.rb', line 21 def id @id end |
#livemode ⇒ Object
本番環境かどうか
24 25 26 |
# File 'lib/payjpv2/models/event_response.rb', line 24 def livemode @livemode end |
#object ⇒ Object
Returns the value of attribute object.
18 19 20 |
# File 'lib/payjpv2/models/event_response.rb', line 18 def object @object end |
#pending_webhooks ⇒ Object
設定された URL への通知が完了していない (2xx のレスポンスが得られていない) webhook の数
30 31 32 |
# File 'lib/payjpv2/models/event_response.rb', line 30 def pending_webhooks @pending_webhooks end |
#type ⇒ Object
イベントの種類
27 28 29 |
# File 'lib/payjpv2/models/event_response.rb', line 27 def type @type end |
#updated_at ⇒ Object
更新日時 (UTC, ISO 8601 形式)
39 40 41 |
# File 'lib/payjpv2/models/event_response.rb', line 39 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/payjpv2/models/event_response.rb', line 308 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PAYJPv2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/payjpv2/models/event_response.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/payjpv2/models/event_response.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/payjpv2/models/event_response.rb', line 64 def self.attribute_map { :object => :object, :id => :id, :livemode => :livemode, :type => :type, :pending_webhooks => :pending_webhooks, :data => :data, :created_at => :created_at, :updated_at => :updated_at } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/payjpv2/models/event_response.rb', line 284 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 |
# File 'lib/payjpv2/models/event_response.rb', line 102 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/payjpv2/models/event_response.rb', line 88 def self.openapi_types { :object => :'String', :id => :'String', :livemode => :'Boolean', :type => :'String', :pending_webhooks => :'Integer', :data => :'Hash<String, Object>', :created_at => :'Time', :updated_at => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/payjpv2/models/event_response.rb', line 256 def ==(o) return true if self.equal?(o) self.class == o.class && object == o.object && id == o.id && livemode == o.livemode && type == o.type && pending_webhooks == o.pending_webhooks && data == o.data && created_at == o.created_at && updated_at == o.updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/payjpv2/models/event_response.rb', line 379 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
271 272 273 |
# File 'lib/payjpv2/models/event_response.rb', line 271 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
277 278 279 |
# File 'lib/payjpv2/models/event_response.rb', line 277 def hash [object, id, livemode, type, pending_webhooks, data, created_at, updated_at].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
355 356 357 |
# File 'lib/payjpv2/models/event_response.rb', line 355 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/payjpv2/models/event_response.rb', line 361 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
349 350 351 |
# File 'lib/payjpv2/models/event_response.rb', line 349 def to_s to_hash.to_s end |