Class: PAYJPv2::PaymentDisputeResponse
- Inherits:
-
Object
- Object
- PAYJPv2::PaymentDisputeResponse
- Defined in:
- lib/payjpv2/models/payment_dispute_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
金額.
-
#created_at ⇒ Object
作成日時 (UTC, ISO 8601 形式).
-
#currency ⇒ Object
通貨コード (ISO 4217).
-
#due_by ⇒ Object
Returns the value of attribute due_by.
-
#id ⇒ Object
PaymentDispute ID.
-
#livemode ⇒ Object
本番環境かどうか.
-
#metadata ⇒ Object
メタデータ.
-
#object ⇒ Object
Returns the value of attribute object.
-
#payment_flow_id ⇒ Object
関連する PaymentFlow の ID.
-
#payment_method_type ⇒ Object
支払い方法の種類.
-
#reason ⇒ Object
Returns the value of attribute reason.
-
#status ⇒ Object
disputeのステータス | 値 | |:—| | pre_warning_needs_response: 利用照会 | | warning_needs_response: 配送保留 | | warning_needs_refund: 配送停止 | | warning_under_review: 加盟店回答済 | | needs_response: チャージバック | | under_review: 反証済 | | lost: チャージバック受入 | | cancel: 取下げ |.
-
#updated_at ⇒ Object
更新日時 (UTC, ISO 8601 形式).
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentDisputeResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PaymentDisputeResponse
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 134 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::PaymentDisputeResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::PaymentDisputeResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:object) self.object = attributes[:object] else self.object = 'payment_dispute' end if attributes.key?(:id) self.id = attributes[:id] else self.id = nil end if attributes.key?(:livemode) self.livemode = attributes[:livemode] else self.livemode = nil end if attributes.key?(:payment_flow_id) self.payment_flow_id = attributes[:payment_flow_id] else self.payment_flow_id = nil end if attributes.key?(:amount) self.amount = attributes[:amount] else self.amount = nil end if attributes.key?(:currency) self.currency = attributes[:currency] else self.currency = nil end if attributes.key?(:status) self.status = attributes[:status] else self.status = nil end if attributes.key?(:reason) self.reason = attributes[:reason] else self.reason = nil end if attributes.key?(:due_by) self.due_by = attributes[:due_by] else self.due_by = nil end if attributes.key?(:payment_method_type) self.payment_method_type = attributes[:payment_method_type] else self.payment_method_type = nil end if attributes.key?(:metadata) if (value = attributes[:metadata]).is_a?(Hash) self. = value end else self. = nil end if attributes.key?(:created_at) self.created_at = attributes[:created_at] else self.created_at = nil end if attributes.key?(:updated_at) self.updated_at = attributes[:updated_at] else self.updated_at = nil end end |
Instance Attribute Details
#amount ⇒ Object
金額
30 31 32 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 30 def amount @amount end |
#created_at ⇒ Object
作成日時 (UTC, ISO 8601 形式)
49 50 51 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 49 def created_at @created_at end |
#currency ⇒ Object
通貨コード (ISO 4217)
33 34 35 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 33 def currency @currency end |
#due_by ⇒ Object
Returns the value of attribute due_by.
40 41 42 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 40 def due_by @due_by end |
#id ⇒ Object
PaymentDispute ID
21 22 23 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 21 def id @id end |
#livemode ⇒ Object
本番環境かどうか
24 25 26 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 24 def livemode @livemode end |
#metadata ⇒ Object
メタデータ
46 47 48 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 46 def @metadata end |
#object ⇒ Object
Returns the value of attribute object.
18 19 20 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 18 def object @object end |
#payment_flow_id ⇒ Object
関連する PaymentFlow の ID
27 28 29 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 27 def payment_flow_id @payment_flow_id end |
#payment_method_type ⇒ Object
支払い方法の種類
43 44 45 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 43 def payment_method_type @payment_method_type end |
#reason ⇒ Object
Returns the value of attribute reason.
38 39 40 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 38 def reason @reason end |
#status ⇒ Object
disputeのステータス | 値 | |:—| | pre_warning_needs_response: 利用照会 | | warning_needs_response: 配送保留 | | warning_needs_refund: 配送停止 | | warning_under_review: 加盟店回答済 | | needs_response: チャージバック | | under_review: 反証済 | | lost: チャージバック受入 | | cancel: 取下げ |
36 37 38 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 36 def status @status end |
#updated_at ⇒ Object
更新日時 (UTC, ISO 8601 形式)
52 53 54 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 52 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 398 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PAYJPv2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
96 97 98 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 96 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
101 102 103 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 101 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 77 def self.attribute_map { :object => :object, :id => :id, :livemode => :livemode, :payment_flow_id => :payment_flow_id, :amount => :amount, :currency => :currency, :status => :status, :reason => :reason, :due_by => :due_by, :payment_method_type => :payment_method_type, :metadata => :metadata, :created_at => :created_at, :updated_at => :updated_at } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 374 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
125 126 127 128 129 130 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 125 def self.openapi_nullable Set.new([ :reason, :due_by, ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 106 def self.openapi_types { :object => :'String', :id => :'String', :livemode => :'Boolean', :payment_flow_id => :'String', :amount => :'Integer', :currency => :'Currency', :status => :'PaymentDisputeStatus', :reason => :'PaymentDisputeReason', :due_by => :'Time', :payment_method_type => :'PaymentMethodTypes', :metadata => :'Hash<String, MetadataValue>', :created_at => :'Time', :updated_at => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 341 def ==(o) return true if self.equal?(o) self.class == o.class && object == o.object && id == o.id && livemode == o.livemode && payment_flow_id == o.payment_flow_id && amount == o.amount && currency == o.currency && status == o.status && reason == o.reason && due_by == o.due_by && payment_method_type == o.payment_method_type && == o. && created_at == o.created_at && updated_at == o.updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 469 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
361 362 363 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 361 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
367 368 369 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 367 def hash [object, id, livemode, payment_flow_id, amount, currency, status, reason, due_by, payment_method_type, , created_at, updated_at].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
445 446 447 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 445 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 451 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
439 440 441 |
# File 'lib/payjpv2/models/payment_dispute_response.rb', line 439 def to_s to_hash.to_s end |