Class: PAYJPv2::PaymentFlowConfirmRequest
- Inherits:
-
Object
- Object
- PAYJPv2::PaymentFlowConfirmRequest
- Defined in:
- lib/payjpv2/models/payment_flow_confirm_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Returns the value of attribute capture_method.
-
#description ⇒ Object
オブジェクトにセットする任意の文字列。.
-
#payment_method_id ⇒ Object
支払い方法 ID。customer_id の指定が必須です。Customer が所持する PaymentMethod のみ指定できます。payment_method_id を指定せず、Customer に default_payment_method_id が設定されている場合はそちらが自動でセットされます。.
-
#payment_method_options ⇒ Object
この PaymentFlow 固有の支払い方法の設定.
-
#payment_method_types ⇒ Object
この PaymentFlow で使用できる支払い方法の種類のリスト。指定しない場合は、PAY.JP は支払い方法の設定から利用可能な支払い方法を動的に表示します。.
-
#return_url ⇒ Object
顧客が支払いを完了後かキャンセルした後にリダイレクトされる URL。アプリにリダイレクトしたい場合は URI Scheme を指定できます。.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentFlowConfirmRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PaymentFlowConfirmRequest
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::PaymentFlowConfirmRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::PaymentFlowConfirmRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:payment_method_id) self.payment_method_id = attributes[:payment_method_id] end if attributes.key?(:payment_method_options) self. = attributes[:payment_method_options] end if attributes.key?(:payment_method_types) if (value = attributes[:payment_method_types]).is_a?(Array) self.payment_method_types = value end end if attributes.key?(:capture_method) self.capture_method = attributes[:capture_method] end if attributes.key?(:return_url) self.return_url = attributes[:return_url] end if attributes.key?(:description) self.description = attributes[:description] end end |
Instance Attribute Details
#capture_method ⇒ Object
Returns the value of attribute capture_method.
27 28 29 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 27 def capture_method @capture_method end |
#description ⇒ Object
オブジェクトにセットする任意の文字列。
33 34 35 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 33 def description @description end |
#payment_method_id ⇒ Object
支払い方法 ID。customer_id の指定が必須です。Customer が所持する PaymentMethod のみ指定できます。payment_method_id を指定せず、Customer に default_payment_method_id が設定されている場合はそちらが自動でセットされます。
19 20 21 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 19 def payment_method_id @payment_method_id end |
#payment_method_options ⇒ Object
この PaymentFlow 固有の支払い方法の設定
22 23 24 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 22 def @payment_method_options end |
#payment_method_types ⇒ Object
この PaymentFlow で使用できる支払い方法の種類のリスト。指定しない場合は、PAY.JP は支払い方法の設定から利用可能な支払い方法を動的に表示します。
25 26 27 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 25 def payment_method_types @payment_method_types end |
#return_url ⇒ Object
顧客が支払いを完了後かキャンセルした後にリダイレクトされる URL。アプリにリダイレクトしたい場合は URI Scheme を指定できます。
30 31 32 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 30 def return_url @return_url end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 193 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PAYJPv2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 58 def self.attribute_map { :payment_method_id => :payment_method_id, :payment_method_options => :payment_method_options, :payment_method_types => :payment_method_types, :capture_method => :capture_method, :return_url => :return_url, :description => :description } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 169 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 96 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 92 def self.openapi_nullable Set.new([ :capture_method, ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 80 def self.openapi_types { :payment_method_id => :'String', :payment_method_options => :'PaymentFlowPaymentMethodOptionsRequest', :payment_method_types => :'Array<PaymentMethodTypes>', :capture_method => :'CaptureMethod', :return_url => :'String', :description => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
143 144 145 146 147 148 149 150 151 152 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 143 def ==(o) return true if self.equal?(o) self.class == o.class && payment_method_id == o.payment_method_id && == o. && payment_method_types == o.payment_method_types && capture_method == o.capture_method && return_url == o.return_url && description == o.description end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 264 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
156 157 158 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 156 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 162 def hash [payment_method_id, , payment_method_types, capture_method, return_url, description].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
240 241 242 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 240 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 246 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
234 235 236 |
# File 'lib/payjpv2/models/payment_flow_confirm_request.rb', line 234 def to_s to_hash.to_s end |