Class: PAYJPv2::PaymentFlowUpdateRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/payjpv2/models/payment_flow_update_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentFlowUpdateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::PaymentFlowUpdateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::PaymentFlowUpdateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:amount)
    self.amount = attributes[:amount]
  end

  if attributes.key?(:customer_id)
    self.customer_id = attributes[:customer_id]
  end

  if attributes.key?(:payment_method_id)
    self.payment_method_id = attributes[:payment_method_id]
  end

  if attributes.key?(:payment_method_options)
    self.payment_method_options = attributes[:payment_method_options]
  end

  if attributes.key?(:payment_method_types)
    if (value = attributes[:payment_method_types]).is_a?(Array)
      self.payment_method_types = value
    end
  end

  if attributes.key?(:return_url)
    self.return_url = attributes[:return_url]
  end

  if attributes.key?(:description)
    self.description = attributes[:description]
  end

  if attributes.key?(:metadata)
    if (value = attributes[:metadata]).is_a?(Hash)
      self. = value
    end
  end
end

Instance Attribute Details

#amountObject

支払い予定の金額。50円以上9,999,999円以下である必要があります。



19
20
21
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 19

def amount
  @amount
end

#customer_idObject

この PaymentFlow に関連付ける顧客の ID



22
23
24
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 22

def customer_id
  @customer_id
end

#descriptionObject

オブジェクトにセットする任意の文字列。



37
38
39
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 37

def description
  @description
end

#metadataObject

キーバリューの任意のデータを格納できます。20件まで登録可能で、空文字列を指定するとそのキーを削除できます。<a href="docs.pay.jp/v2/guide/developers/metadata">詳細はメタデータのドキュメントを参照してください。</a>



40
41
42
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 40

def 
  @metadata
end

#payment_method_idObject

支払い方法 ID。customer_id の指定が必須です。Customer が所持する PaymentMethod のみ指定できます。payment_method_id を指定せず、Customer に default_payment_method_id が設定されている場合はそちらが自動でセットされます。



25
26
27
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 25

def payment_method_id
  @payment_method_id
end

#payment_method_optionsObject

この PaymentFlow 固有の支払い方法の設定



28
29
30
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 28

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

この PaymentFlow で使用できる支払い方法の種類のリスト。指定しない場合は、PAY.JP は支払い方法の設定から利用可能な支払い方法を動的に表示します。



31
32
33
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 31

def payment_method_types
  @payment_method_types
end

#return_urlObject

顧客が支払いを完了後かキャンセルした後にリダイレクトされる URL。アプリにリダイレクトしたい場合は URI Scheme を指定できます。



34
35
36
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 34

def return_url
  @return_url
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 211

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PAYJPv2.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 43

def self.attribute_map
  {
    :amount => :amount,
    :customer_id => :customer_id,
    :payment_method_id => :payment_method_id,
    :payment_method_options => :payment_method_options,
    :payment_method_types => :payment_method_types,
    :return_url => :return_url,
    :description => :description,
    :metadata => :metadata
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 187

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 67

def self.openapi_types
  {
    :amount => :'Integer',
    :customer_id => :'String',
    :payment_method_id => :'String',
    :payment_method_options => :'PaymentFlowPaymentMethodOptionsRequest',
    :payment_method_types => :'Array<PaymentMethodTypes>',
    :return_url => :'String',
    :description => :'String',
    :metadata => :'Hash<String, MetadataValue>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 159

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      customer_id == o.customer_id &&
      payment_method_id == o.payment_method_id &&
      payment_method_options == o.payment_method_options &&
      payment_method_types == o.payment_method_types &&
      return_url == o.return_url &&
      description == o.description &&
       == o.
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 282

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


174
175
176
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 174

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



180
181
182
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 180

def hash
  [amount, customer_id, payment_method_id, payment_method_options, payment_method_types, return_url, description, ].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 258

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 264

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



252
253
254
# File 'lib/payjpv2/models/payment_flow_update_request.rb', line 252

def to_s
  to_hash.to_s
end