Class: PAYJPv2::PaymentFlowsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/payjpv2/api/payment_flows_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PaymentFlowsApi

Returns a new instance of PaymentFlowsApi.



19
20
21
# File 'lib/payjpv2/api/payment_flows_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/payjpv2/api/payment_flows_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#cancel_payment_flow(payment_flow_id, opts = {}) ⇒ PaymentFlowResponse, Array

Cancel Payment Flow

Parameters:

  • payment_flow_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :payment_flow_cancel_request (PaymentFlowCancelRequest)
  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (PaymentFlowResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/payjpv2/api/payment_flows_api.rb', line 29

def cancel_payment_flow(payment_flow_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentFlowsApi.cancel_payment_flow ...'
  end
  # verify the required parameter 'payment_flow_id' is set
  if @api_client.config.client_side_validation && payment_flow_id.nil?
    raise ArgumentError, "Missing the required parameter 'payment_flow_id' when calling PaymentFlowsApi.cancel_payment_flow"
  end
  # resource path
  local_var_path = '/v2/payment_flows/{payment_flow_id}/cancel'.sub('{' + 'payment_flow_id' + '}', CGI.escape(payment_flow_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:payment_flow_cancel_request])

  # return_type
  return_type = opts[:debug_return_type] || 'PaymentFlowResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"PaymentFlowsApi.cancel_payment_flow",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentFlowsApi#cancel_payment_flow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end

#capture_payment_flow(payment_flow_id, opts = {}) ⇒ PaymentFlowResponse, Array

Capture Payment Flow

Parameters:

  • payment_flow_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :payment_flow_capture_request (PaymentFlowCaptureRequest)
  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (PaymentFlowResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/payjpv2/api/payment_flows_api.rb', line 95

def capture_payment_flow(payment_flow_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentFlowsApi.capture_payment_flow ...'
  end
  # verify the required parameter 'payment_flow_id' is set
  if @api_client.config.client_side_validation && payment_flow_id.nil?
    raise ArgumentError, "Missing the required parameter 'payment_flow_id' when calling PaymentFlowsApi.capture_payment_flow"
  end
  # resource path
  local_var_path = '/v2/payment_flows/{payment_flow_id}/capture'.sub('{' + 'payment_flow_id' + '}', CGI.escape(payment_flow_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:payment_flow_capture_request])

  # return_type
  return_type = opts[:debug_return_type] || 'PaymentFlowResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"PaymentFlowsApi.capture_payment_flow",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentFlowsApi#capture_payment_flow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end

#confirm_payment_flow(payment_flow_id, opts = {}) ⇒ PaymentFlowResponse, Array

Confirm Payment Flow

Parameters:

  • payment_flow_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :payment_flow_confirm_request (PaymentFlowConfirmRequest)
  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (PaymentFlowResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/payjpv2/api/payment_flows_api.rb', line 161

def confirm_payment_flow(payment_flow_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentFlowsApi.confirm_payment_flow ...'
  end
  # verify the required parameter 'payment_flow_id' is set
  if @api_client.config.client_side_validation && payment_flow_id.nil?
    raise ArgumentError, "Missing the required parameter 'payment_flow_id' when calling PaymentFlowsApi.confirm_payment_flow"
  end
  # resource path
  local_var_path = '/v2/payment_flows/{payment_flow_id}/confirm'.sub('{' + 'payment_flow_id' + '}', CGI.escape(payment_flow_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:payment_flow_confirm_request])

  # return_type
  return_type = opts[:debug_return_type] || 'PaymentFlowResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"PaymentFlowsApi.confirm_payment_flow",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentFlowsApi#confirm_payment_flow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end

#create_payment_flow(payment_flow_create_request, opts = {}) ⇒ PaymentFlowResponse, Array

Create Payment Flow

Parameters:

Options Hash (opts):

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (PaymentFlowResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/payjpv2/api/payment_flows_api.rb', line 226

def create_payment_flow(payment_flow_create_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentFlowsApi.create_payment_flow ...'
  end
  # verify the required parameter 'payment_flow_create_request' is set
  if @api_client.config.client_side_validation && payment_flow_create_request.nil?
    raise ArgumentError, "Missing the required parameter 'payment_flow_create_request' when calling PaymentFlowsApi.create_payment_flow"
  end
  # resource path
  local_var_path = '/v2/payment_flows'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(payment_flow_create_request)

  # return_type
  return_type = opts[:debug_return_type] || 'PaymentFlowResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"PaymentFlowsApi.create_payment_flow",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentFlowsApi#create_payment_flow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end

#get_all_payment_flows(opts = {}) ⇒ PaymentFlowListResponse, Array

Get All Payment Flows

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    取得するデータの最大件数 (default to 10)

  • :starting_after (String)

    このIDより後のデータを取得

  • :ending_before (String)

    このIDより前のデータを取得

  • :customer_id (String)

    指定した顧客のデータのみを取得

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/payjpv2/api/payment_flows_api.rb', line 294

def get_all_payment_flows(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentFlowsApi.get_all_payment_flows ...'
  end
  if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] > 100
    raise ArgumentError, 'invalid value for "opts[:limit]" when calling PaymentFlowsApi.get_all_payment_flows, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] < 1
    raise ArgumentError, 'invalid value for "opts[:limit]" when calling PaymentFlowsApi.get_all_payment_flows, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/v2/payment_flows'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:limit] = opts[:limit] if !opts[:limit].nil?
  query_params[:starting_after] = opts[:starting_after] if !opts[:starting_after].nil?
  query_params[:ending_before] = opts[:ending_before] if !opts[:ending_before].nil?
  query_params[:customer_id] = opts[:customer_id] if !opts[:customer_id].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaymentFlowListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"PaymentFlowsApi.get_all_payment_flows",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentFlowsApi#get_all_payment_flows\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end

#get_payment_flow(payment_flow_id, opts = {}) ⇒ PaymentFlowResponse, Array

Get Payment Flow

Parameters:

  • payment_flow_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (PaymentFlowResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/payjpv2/api/payment_flows_api.rb', line 362

def get_payment_flow(payment_flow_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentFlowsApi.get_payment_flow ...'
  end
  # verify the required parameter 'payment_flow_id' is set
  if @api_client.config.client_side_validation && payment_flow_id.nil?
    raise ArgumentError, "Missing the required parameter 'payment_flow_id' when calling PaymentFlowsApi.get_payment_flow"
  end
  # resource path
  local_var_path = '/v2/payment_flows/{payment_flow_id}'.sub('{' + 'payment_flow_id' + '}', CGI.escape(payment_flow_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaymentFlowResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"PaymentFlowsApi.get_payment_flow",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentFlowsApi#get_payment_flow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end

#get_payment_flow_refunds(payment_flow_id, opts = {}) ⇒ PaymentRefundListResponse, Array

Get Payment Flow Refunds Payment Flowに紐づくRefundsをリスト取得する

Parameters:

  • payment_flow_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    取得するデータの最大件数 (default to 10)

  • :starting_after (String)

    このIDより後のデータを取得

  • :ending_before (String)

    このIDより前のデータを取得

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/payjpv2/api/payment_flows_api.rb', line 426

def get_payment_flow_refunds(payment_flow_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentFlowsApi.get_payment_flow_refunds ...'
  end
  # verify the required parameter 'payment_flow_id' is set
  if @api_client.config.client_side_validation && payment_flow_id.nil?
    raise ArgumentError, "Missing the required parameter 'payment_flow_id' when calling PaymentFlowsApi.get_payment_flow_refunds"
  end
  if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] > 100
    raise ArgumentError, 'invalid value for "opts[:limit]" when calling PaymentFlowsApi.get_payment_flow_refunds, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] < 1
    raise ArgumentError, 'invalid value for "opts[:limit]" when calling PaymentFlowsApi.get_payment_flow_refunds, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/v2/payment_flows/{payment_flow_id}/refunds'.sub('{' + 'payment_flow_id' + '}', CGI.escape(payment_flow_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:limit] = opts[:limit] if !opts[:limit].nil?
  query_params[:starting_after] = opts[:starting_after] if !opts[:starting_after].nil?
  query_params[:ending_before] = opts[:ending_before] if !opts[:ending_before].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaymentRefundListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"PaymentFlowsApi.get_payment_flow_refunds",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentFlowsApi#get_payment_flow_refunds\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end

#update_payment_flow(payment_flow_id, payment_flow_update_request, opts = {}) ⇒ PaymentFlowResponse, Array

Update Payment Flow

Parameters:

  • payment_flow_id (String)
  • payment_flow_update_request (PaymentFlowUpdateRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (PaymentFlowResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
# File 'lib/payjpv2/api/payment_flows_api.rb', line 498

def update_payment_flow(payment_flow_id, payment_flow_update_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentFlowsApi.update_payment_flow ...'
  end
  # verify the required parameter 'payment_flow_id' is set
  if @api_client.config.client_side_validation && payment_flow_id.nil?
    raise ArgumentError, "Missing the required parameter 'payment_flow_id' when calling PaymentFlowsApi.update_payment_flow"
  end
  # verify the required parameter 'payment_flow_update_request' is set
  if @api_client.config.client_side_validation && payment_flow_update_request.nil?
    raise ArgumentError, "Missing the required parameter 'payment_flow_update_request' when calling PaymentFlowsApi.update_payment_flow"
  end
  # resource path
  local_var_path = '/v2/payment_flows/{payment_flow_id}'.sub('{' + 'payment_flow_id' + '}', CGI.escape(payment_flow_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(payment_flow_update_request)

  # return_type
  return_type = opts[:debug_return_type] || 'PaymentFlowResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"PaymentFlowsApi.update_payment_flow",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentFlowsApi#update_payment_flow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end