Class: PAYJPv2::PaymentMethodCardResponse
- Inherits:
-
Object
- Object
- PAYJPv2::PaymentMethodCardResponse
- Defined in:
- lib/payjpv2/models/payment_method_card_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
請求先情報.
-
#card ⇒ Object
カード情報.
-
#created_at ⇒ Object
作成日時 (UTC, ISO 8601 形式).
-
#customer_id ⇒ Object
Returns the value of attribute customer_id.
-
#detached_at ⇒ Object
Returns the value of attribute detached_at.
-
#id ⇒ Object
ID.
-
#livemode ⇒ Object
本番環境かどうか.
-
#metadata ⇒ Object
メタデータ.
-
#object ⇒ Object
Returns the value of attribute object.
-
#type ⇒ Object
Returns the value of attribute type.
-
#updated_at ⇒ Object
更新日時 (UTC, ISO 8601 形式).
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentMethodCardResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PaymentMethodCardResponse
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 123 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::PaymentMethodCardResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::PaymentMethodCardResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:object) self.object = attributes[:object] else self.object = 'payment_method' end if attributes.key?(:id) self.id = attributes[:id] else self.id = nil end if attributes.key?(:livemode) self.livemode = attributes[:livemode] else self.livemode = nil end if attributes.key?(:type) self.type = attributes[:type] else self.type = nil end if attributes.key?(:customer_id) self.customer_id = attributes[:customer_id] else self.customer_id = nil end if attributes.key?(:detached_at) self.detached_at = attributes[:detached_at] else self.detached_at = nil end if attributes.key?(:metadata) if (value = attributes[:metadata]).is_a?(Hash) self. = value end else self. = nil end if attributes.key?(:created_at) self.created_at = attributes[:created_at] else self.created_at = nil end if attributes.key?(:updated_at) self.updated_at = attributes[:updated_at] else self.updated_at = nil end if attributes.key?(:billing_details) self.billing_details = attributes[:billing_details] else self.billing_details = nil end if attributes.key?(:card) self.card = attributes[:card] else self.card = nil end end |
Instance Attribute Details
#billing_details ⇒ Object
請求先情報
42 43 44 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 42 def billing_details @billing_details end |
#card ⇒ Object
カード情報
45 46 47 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 45 def card @card end |
#created_at ⇒ Object
作成日時 (UTC, ISO 8601 形式)
36 37 38 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 36 def created_at @created_at end |
#customer_id ⇒ Object
Returns the value of attribute customer_id.
28 29 30 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 28 def customer_id @customer_id end |
#detached_at ⇒ Object
Returns the value of attribute detached_at.
30 31 32 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 30 def detached_at @detached_at end |
#id ⇒ Object
ID
21 22 23 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 21 def id @id end |
#livemode ⇒ Object
本番環境かどうか
24 25 26 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 24 def livemode @livemode end |
#metadata ⇒ Object
メタデータ
33 34 35 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 33 def @metadata end |
#object ⇒ Object
Returns the value of attribute object.
18 19 20 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 18 def object @object end |
#type ⇒ Object
Returns the value of attribute type.
26 27 28 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 26 def type @type end |
#updated_at ⇒ Object
更新日時 (UTC, ISO 8601 形式)
39 40 41 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 39 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 353 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PAYJPv2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
87 88 89 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 87 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 92 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 70 def self.attribute_map { :object => :object, :id => :id, :livemode => :livemode, :type => :type, :customer_id => :customer_id, :detached_at => :detached_at, :metadata => :metadata, :created_at => :created_at, :updated_at => :updated_at, :billing_details => :billing_details, :card => :card } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 329 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
114 115 116 117 118 119 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 114 def self.openapi_nullable Set.new([ :customer_id, :detached_at, ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 97 def self.openapi_types { :object => :'String', :id => :'String', :livemode => :'Boolean', :type => :'String', :customer_id => :'String', :detached_at => :'Time', :metadata => :'Hash<String, MetadataValue>', :created_at => :'Time', :updated_at => :'Time', :billing_details => :'PaymentMethodBillingDetailsResponse', :card => :'PaymentMethodCardDetailsResponse' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 298 def ==(o) return true if self.equal?(o) self.class == o.class && object == o.object && id == o.id && livemode == o.livemode && type == o.type && customer_id == o.customer_id && detached_at == o.detached_at && == o. && created_at == o.created_at && updated_at == o.updated_at && billing_details == o.billing_details && card == o.card end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 424 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
316 317 318 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 316 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
322 323 324 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 322 def hash [object, id, livemode, type, customer_id, detached_at, , created_at, updated_at, billing_details, card].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
400 401 402 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 400 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 406 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
394 395 396 |
# File 'lib/payjpv2/models/payment_method_card_response.rb', line 394 def to_s to_hash.to_s end |