Class: PAYJPv2::PaymentMethodConfigurationDetailsResponse
- Inherits:
-
Object
- Object
- PAYJPv2::PaymentMethodConfigurationDetailsResponse
- Defined in:
- lib/payjpv2/models/payment_method_configuration_details_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active ⇒ Object
設定が有効かどうか.
-
#apple_pay ⇒ Object
Apple Pay の設定.
-
#card ⇒ Object
カードの設定.
-
#id ⇒ Object
支払い方法設定 ID.
-
#livemode ⇒ Object
本番環境かどうか.
-
#name ⇒ Object
Returns the value of attribute name.
-
#object ⇒ Object
Returns the value of attribute object.
-
#paypay ⇒ Object
PayPay の設定.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentMethodConfigurationDetailsResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PaymentMethodConfigurationDetailsResponse
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::PaymentMethodConfigurationDetailsResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::PaymentMethodConfigurationDetailsResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:object) self.object = attributes[:object] else self.object = 'payment_method_configuration' end if attributes.key?(:id) self.id = attributes[:id] else self.id = nil end if attributes.key?(:livemode) self.livemode = attributes[:livemode] else self.livemode = nil end if attributes.key?(:active) self.active = attributes[:active] else self.active = nil end if attributes.key?(:name) self.name = attributes[:name] else self.name = nil end if attributes.key?(:paypay) self.paypay = attributes[:paypay] else self.paypay = nil end if attributes.key?(:card) self.card = attributes[:card] else self.card = nil end if attributes.key?(:apple_pay) self.apple_pay = attributes[:apple_pay] else self.apple_pay = nil end end |
Instance Attribute Details
#active ⇒ Object
設定が有効かどうか
27 28 29 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 27 def active @active end |
#apple_pay ⇒ Object
Apple Pay の設定
38 39 40 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 38 def apple_pay @apple_pay end |
#card ⇒ Object
カードの設定
35 36 37 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 35 def card @card end |
#id ⇒ Object
支払い方法設定 ID
21 22 23 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 21 def id @id end |
#livemode ⇒ Object
本番環境かどうか
24 25 26 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 24 def livemode @livemode end |
#name ⇒ Object
Returns the value of attribute name.
29 30 31 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 29 def name @name end |
#object ⇒ Object
Returns the value of attribute object.
18 19 20 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 18 def object @object end |
#paypay ⇒ Object
PayPay の設定
32 33 34 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 32 def paypay @paypay end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 296 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PAYJPv2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 63 def self.attribute_map { :object => :object, :id => :id, :livemode => :livemode, :active => :active, :name => :name, :paypay => :paypay, :card => :card, :apple_pay => :apple_pay } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 272 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 105 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 101 def self.openapi_nullable Set.new([ :name, ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 87 def self.openapi_types { :object => :'String', :id => :'String', :livemode => :'Boolean', :active => :'Boolean', :name => :'String', :paypay => :'PaymentMethodConfigurationSettingResponse', :card => :'PaymentMethodConfigurationSettingResponse', :apple_pay => :'PaymentMethodConfigurationSettingResponse' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 244 def ==(o) return true if self.equal?(o) self.class == o.class && object == o.object && id == o.id && livemode == o.livemode && active == o.active && name == o.name && paypay == o.paypay && card == o.card && apple_pay == o.apple_pay end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 367 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
259 260 261 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 259 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
265 266 267 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 265 def hash [object, id, livemode, active, name, paypay, card, apple_pay].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
343 344 345 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 343 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 349 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
337 338 339 |
# File 'lib/payjpv2/models/payment_method_configuration_details_response.rb', line 337 def to_s to_hash.to_s end |