Class: PAYJPv2::PaymentRefundsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/payjpv2/api/payment_refunds_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PaymentRefundsApi

Returns a new instance of PaymentRefundsApi.



19
20
21
# File 'lib/payjpv2/api/payment_refunds_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/payjpv2/api/payment_refunds_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_payment_refund(payment_refund_create_request, opts = {}) ⇒ PaymentRefundResponse, Array

Create Payment Refund

Parameters:

Options Hash (opts):

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (PaymentRefundResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/payjpv2/api/payment_refunds_api.rb', line 28

def create_payment_refund(payment_refund_create_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentRefundsApi.create_payment_refund ...'
  end
  # verify the required parameter 'payment_refund_create_request' is set
  if @api_client.config.client_side_validation && payment_refund_create_request.nil?
    raise ArgumentError, "Missing the required parameter 'payment_refund_create_request' when calling PaymentRefundsApi.create_payment_refund"
  end
  # resource path
  local_var_path = '/v2/payment_refunds'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(payment_refund_create_request)

  # return_type
  return_type = opts[:debug_return_type] || 'PaymentRefundResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"PaymentRefundsApi.create_payment_refund",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentRefundsApi#create_payment_refund\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end

#get_all_payment_refunds(opts = {}) ⇒ PaymentRefundListResponse, Array

Get All Payment Refunds

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    取得するデータの最大件数 (default to 10)

  • :starting_after (String)

    このIDより後のデータを取得

  • :ending_before (String)

    このIDより前のデータを取得

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/payjpv2/api/payment_refunds_api.rb', line 95

def get_all_payment_refunds(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentRefundsApi.get_all_payment_refunds ...'
  end
  if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] > 100
    raise ArgumentError, 'invalid value for "opts[:limit]" when calling PaymentRefundsApi.get_all_payment_refunds, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] < 1
    raise ArgumentError, 'invalid value for "opts[:limit]" when calling PaymentRefundsApi.get_all_payment_refunds, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/v2/payment_refunds'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:limit] = opts[:limit] if !opts[:limit].nil?
  query_params[:starting_after] = opts[:starting_after] if !opts[:starting_after].nil?
  query_params[:ending_before] = opts[:ending_before] if !opts[:ending_before].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaymentRefundListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"PaymentRefundsApi.get_all_payment_refunds",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentRefundsApi#get_all_payment_refunds\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end

#get_payment_refund(payment_refund_id, opts = {}) ⇒ PaymentRefundResponse, Array

Get Payment Refund

Parameters:

  • payment_refund_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (PaymentRefundResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/payjpv2/api/payment_refunds_api.rb', line 162

def get_payment_refund(payment_refund_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentRefundsApi.get_payment_refund ...'
  end
  # verify the required parameter 'payment_refund_id' is set
  if @api_client.config.client_side_validation && payment_refund_id.nil?
    raise ArgumentError, "Missing the required parameter 'payment_refund_id' when calling PaymentRefundsApi.get_payment_refund"
  end
  # resource path
  local_var_path = '/v2/payment_refunds/{payment_refund_id}'.sub('{' + 'payment_refund_id' + '}', CGI.escape(payment_refund_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaymentRefundResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"PaymentRefundsApi.get_payment_refund",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentRefundsApi#get_payment_refund\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end

#update_payment_refund(payment_refund_id, payment_refund_update_request, opts = {}) ⇒ PaymentRefundResponse, Array

Update Payment Refund

Parameters:

  • payment_refund_id (String)
  • payment_refund_update_request (PaymentRefundUpdateRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (PaymentRefundResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/payjpv2/api/payment_refunds_api.rb', line 223

def update_payment_refund(payment_refund_id, payment_refund_update_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentRefundsApi.update_payment_refund ...'
  end
  # verify the required parameter 'payment_refund_id' is set
  if @api_client.config.client_side_validation && payment_refund_id.nil?
    raise ArgumentError, "Missing the required parameter 'payment_refund_id' when calling PaymentRefundsApi.update_payment_refund"
  end
  # verify the required parameter 'payment_refund_update_request' is set
  if @api_client.config.client_side_validation && payment_refund_update_request.nil?
    raise ArgumentError, "Missing the required parameter 'payment_refund_update_request' when calling PaymentRefundsApi.update_payment_refund"
  end
  # resource path
  local_var_path = '/v2/payment_refunds/{payment_refund_id}'.sub('{' + 'payment_refund_id' + '}', CGI.escape(payment_refund_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(payment_refund_update_request)

  # return_type
  return_type = opts[:debug_return_type] || 'PaymentRefundResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"PaymentRefundsApi.update_payment_refund",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentRefundsApi#update_payment_refund\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end