Class: PAYJPv2::PaymentTransactionResponse
- Inherits:
-
Object
- Object
- PAYJPv2::PaymentTransactionResponse
- Defined in:
- lib/payjpv2/models/payment_transaction_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
金額.
-
#created_at ⇒ Object
作成日時 (UTC, ISO 8601 形式).
-
#currency ⇒ Object
通貨.
-
#fee ⇒ Object
手数料.
-
#fee_rate ⇒ Object
手数料率.
-
#id ⇒ Object
決済トランザクション ID.
-
#livemode ⇒ Object
本番環境かどうか.
-
#object ⇒ Object
Returns the value of attribute object.
-
#payment_method_type ⇒ Object
支払い方法の種類.
-
#resource_id ⇒ Object
PaymentTransaction 生成の元になったリソースの ID.
-
#term_id ⇒ Object
集計区間 ID.
-
#type ⇒ Object
PaymentTransaction の種類 | 値 | |:—| | payment: 支払い | | refund: 返金 | | chargeback: チャージバック | | chargeback_cancel: チャージバックのキャンセル |.
-
#updated_at ⇒ Object
更新日時 (UTC, ISO 8601 形式).
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentTransactionResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PaymentTransactionResponse
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 134 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::PaymentTransactionResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::PaymentTransactionResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:object) self.object = attributes[:object] else self.object = 'payment_transaction' end if attributes.key?(:id) self.id = attributes[:id] else self.id = nil end if attributes.key?(:livemode) self.livemode = attributes[:livemode] else self.livemode = nil end if attributes.key?(:resource_id) self.resource_id = attributes[:resource_id] else self.resource_id = nil end if attributes.key?(:amount) self.amount = attributes[:amount] else self.amount = nil end if attributes.key?(:currency) self.currency = attributes[:currency] else self.currency = nil end if attributes.key?(:fee_rate) self.fee_rate = attributes[:fee_rate] else self.fee_rate = nil end if attributes.key?(:fee) self.fee = attributes[:fee] else self.fee = nil end if attributes.key?(:type) self.type = attributes[:type] else self.type = nil end if attributes.key?(:payment_method_type) self.payment_method_type = attributes[:payment_method_type] else self.payment_method_type = nil end if attributes.key?(:term_id) self.term_id = attributes[:term_id] else self.term_id = nil end if attributes.key?(:created_at) self.created_at = attributes[:created_at] else self.created_at = nil end if attributes.key?(:updated_at) self.updated_at = attributes[:updated_at] else self.updated_at = nil end end |
Instance Attribute Details
#amount ⇒ Object
金額
30 31 32 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 30 def amount @amount end |
#created_at ⇒ Object
作成日時 (UTC, ISO 8601 形式)
51 52 53 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 51 def created_at @created_at end |
#currency ⇒ Object
通貨
33 34 35 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 33 def currency @currency end |
#fee ⇒ Object
手数料
39 40 41 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 39 def fee @fee end |
#fee_rate ⇒ Object
手数料率
36 37 38 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 36 def fee_rate @fee_rate end |
#id ⇒ Object
決済トランザクション ID
21 22 23 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 21 def id @id end |
#livemode ⇒ Object
本番環境かどうか
24 25 26 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 24 def livemode @livemode end |
#object ⇒ Object
Returns the value of attribute object.
18 19 20 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 18 def object @object end |
#payment_method_type ⇒ Object
支払い方法の種類
45 46 47 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 45 def payment_method_type @payment_method_type end |
#resource_id ⇒ Object
PaymentTransaction 生成の元になったリソースの ID
27 28 29 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 27 def resource_id @resource_id end |
#term_id ⇒ Object
集計区間 ID
48 49 50 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 48 def term_id @term_id end |
#type ⇒ Object
PaymentTransaction の種類 | 値 | |:—| | payment: 支払い | | refund: 返金 | | chargeback: チャージバック | | chargeback_cancel: チャージバックのキャンセル |
42 43 44 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 42 def type @type end |
#updated_at ⇒ Object
更新日時 (UTC, ISO 8601 形式)
54 55 56 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 54 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 421 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PAYJPv2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
98 99 100 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 98 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
103 104 105 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 103 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 79 def self.attribute_map { :object => :object, :id => :id, :livemode => :livemode, :resource_id => :resource_id, :amount => :amount, :currency => :currency, :fee_rate => :fee_rate, :fee => :fee, :type => :type, :payment_method_type => :payment_method_type, :term_id => :term_id, :created_at => :created_at, :updated_at => :updated_at } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 397 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
127 128 129 130 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 127 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 108 def self.openapi_types { :object => :'String', :id => :'String', :livemode => :'Boolean', :resource_id => :'String', :amount => :'Integer', :currency => :'Currency', :fee_rate => :'String', :fee => :'Integer', :type => :'PaymentTransactionType', :payment_method_type => :'PaymentMethodTypes', :term_id => :'String', :created_at => :'Time', :updated_at => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 364 def ==(o) return true if self.equal?(o) self.class == o.class && object == o.object && id == o.id && livemode == o.livemode && resource_id == o.resource_id && amount == o.amount && currency == o.currency && fee_rate == o.fee_rate && fee == o.fee && type == o.type && payment_method_type == o.payment_method_type && term_id == o.term_id && created_at == o.created_at && updated_at == o.updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 492 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
384 385 386 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 384 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
390 391 392 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 390 def hash [object, id, livemode, resource_id, amount, currency, fee_rate, fee, type, payment_method_type, term_id, created_at, updated_at].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
468 469 470 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 468 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 474 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
462 463 464 |
# File 'lib/payjpv2/models/payment_transaction_response.rb', line 462 def to_s to_hash.to_s end |