Class: PAYJPv2::PaymentTransactionsApi
- Inherits:
-
Object
- Object
- PAYJPv2::PaymentTransactionsApi
- Defined in:
- lib/payjpv2/api/payment_transactions_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_all_payment_transactions(opts = {}) ⇒ PaymentTransactionListResponse, Array
Get All Payment Transactions.
-
#get_payment_transaction(payment_transaction_id, opts = {}) ⇒ PaymentTransactionResponse, Array
Get Payment Transaction.
-
#initialize(api_client = ApiClient.default) ⇒ PaymentTransactionsApi
constructor
A new instance of PaymentTransactionsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PaymentTransactionsApi
Returns a new instance of PaymentTransactionsApi.
19 20 21 |
# File 'lib/payjpv2/api/payment_transactions_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/payjpv2/api/payment_transactions_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_all_payment_transactions(opts = {}) ⇒ PaymentTransactionListResponse, Array
Get All Payment Transactions
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/payjpv2/api/payment_transactions_api.rb', line 33 def get_all_payment_transactions(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PaymentTransactionsApi.get_all_payment_transactions ...' end if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] > 100 raise ArgumentError, 'invalid value for "opts[:limit]" when calling PaymentTransactionsApi.get_all_payment_transactions, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] < 1 raise ArgumentError, 'invalid value for "opts[:limit]" when calling PaymentTransactionsApi.get_all_payment_transactions, must be greater than or equal to 1.' end # resource path local_var_path = '/v2/payment_transactions' # query parameters query_params = opts[:query_params] || {} query_params[:limit] = opts[:limit] if !opts[:limit].nil? query_params[:starting_after] = opts[:starting_after] if !opts[:starting_after].nil? query_params[:ending_before] = opts[:ending_before] if !opts[:ending_before].nil? query_params[:term_id] = opts[:term_id] if !opts[:term_id].nil? query_params[:type] = opts[:type] if !opts[:type].nil? query_params[:payment_method_type] = opts[:payment_method_type] if !opts[:payment_method_type].nil? # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaymentTransactionListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"PaymentTransactionsApi.get_all_payment_transactions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentTransactionsApi#get_all_payment_transactions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |
#get_payment_transaction(payment_transaction_id, opts = {}) ⇒ PaymentTransactionResponse, Array
Get Payment Transaction
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/payjpv2/api/payment_transactions_api.rb', line 103 def get_payment_transaction(payment_transaction_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PaymentTransactionsApi.get_payment_transaction ...' end # verify the required parameter 'payment_transaction_id' is set if @api_client.config.client_side_validation && payment_transaction_id.nil? raise ArgumentError, "Missing the required parameter 'payment_transaction_id' when calling PaymentTransactionsApi.get_payment_transaction" end # resource path local_var_path = '/v2/payment_transactions/{payment_transaction_id}'.sub('{' + 'payment_transaction_id' + '}', CGI.escape(payment_transaction_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaymentTransactionResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"PaymentTransactionsApi.get_payment_transaction", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentTransactionsApi#get_payment_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |