Class: PAYJPv2::PriceCreateRequest
- Inherits:
-
Object
- Object
- PAYJPv2::PriceCreateRequest
- Defined in:
- lib/payjpv2/models/price_create_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active ⇒ Object
価格が有効かどうか.
-
#currency ⇒ Object
価格の通貨。現在は ‘jpy` のみサポートしています。.
-
#id ⇒ Object
料金 ID.
-
#lookup_key ⇒ Object
この価格を検索するためのキー.
-
#metadata ⇒ Object
キーバリューの任意のデータを格納できます。20件まで登録可能で、空文字列を指定するとそのキーを削除できます。<a href="docs.pay.jp/v2/guide/developers/metadata">詳細はメタデータのドキュメントを参照してください。</a>.
-
#nickname ⇒ Object
価格の名称。PAY.JP の管理画面で識別するためのもので、顧客には表示されません。.
-
#product_id ⇒ Object
この価格が紐付く商品の ID.
-
#unit_amount ⇒ Object
価格の単価.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PriceCreateRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PriceCreateRequest
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/payjpv2/models/price_create_request.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::PriceCreateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::PriceCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:product_id) self.product_id = attributes[:product_id] else self.product_id = nil end if attributes.key?(:unit_amount) self.unit_amount = attributes[:unit_amount] else self.unit_amount = nil end if attributes.key?(:currency) self.currency = attributes[:currency] else self.currency = nil end if attributes.key?(:id) self.id = attributes[:id] end if attributes.key?(:active) self.active = attributes[:active] else self.active = true end if attributes.key?(:nickname) self.nickname = attributes[:nickname] end if attributes.key?(:lookup_key) self.lookup_key = attributes[:lookup_key] end if attributes.key?(:metadata) if (value = attributes[:metadata]).is_a?(Hash) self. = value end end end |
Instance Attribute Details
#active ⇒ Object
価格が有効かどうか
31 32 33 |
# File 'lib/payjpv2/models/price_create_request.rb', line 31 def active @active end |
#currency ⇒ Object
価格の通貨。現在は ‘jpy` のみサポートしています。
25 26 27 |
# File 'lib/payjpv2/models/price_create_request.rb', line 25 def currency @currency end |
#id ⇒ Object
料金 ID
28 29 30 |
# File 'lib/payjpv2/models/price_create_request.rb', line 28 def id @id end |
#lookup_key ⇒ Object
この価格を検索するためのキー
37 38 39 |
# File 'lib/payjpv2/models/price_create_request.rb', line 37 def lookup_key @lookup_key end |
#metadata ⇒ Object
キーバリューの任意のデータを格納できます。20件まで登録可能で、空文字列を指定するとそのキーを削除できます。<a href="docs.pay.jp/v2/guide/developers/metadata">詳細はメタデータのドキュメントを参照してください。</a>
40 41 42 |
# File 'lib/payjpv2/models/price_create_request.rb', line 40 def @metadata end |
#nickname ⇒ Object
価格の名称。PAY.JP の管理画面で識別するためのもので、顧客には表示されません。
34 35 36 |
# File 'lib/payjpv2/models/price_create_request.rb', line 34 def nickname @nickname end |
#product_id ⇒ Object
この価格が紐付く商品の ID
19 20 21 |
# File 'lib/payjpv2/models/price_create_request.rb', line 19 def product_id @product_id end |
#unit_amount ⇒ Object
価格の単価
22 23 24 |
# File 'lib/payjpv2/models/price_create_request.rb', line 22 def unit_amount @unit_amount end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/payjpv2/models/price_create_request.rb', line 255 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PAYJPv2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/payjpv2/models/price_create_request.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/payjpv2/models/price_create_request.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/payjpv2/models/price_create_request.rb', line 65 def self.attribute_map { :product_id => :product_id, :unit_amount => :unit_amount, :currency => :currency, :id => :id, :active => :active, :nickname => :nickname, :lookup_key => :lookup_key, :metadata => :metadata } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/payjpv2/models/price_create_request.rb', line 231 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/payjpv2/models/price_create_request.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/payjpv2/models/price_create_request.rb', line 89 def self.openapi_types { :product_id => :'String', :unit_amount => :'Integer', :currency => :'Currency', :id => :'String', :active => :'Boolean', :nickname => :'String', :lookup_key => :'String', :metadata => :'Hash<String, MetadataValue>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/payjpv2/models/price_create_request.rb', line 203 def ==(o) return true if self.equal?(o) self.class == o.class && product_id == o.product_id && unit_amount == o.unit_amount && currency == o.currency && id == o.id && active == o.active && nickname == o.nickname && lookup_key == o.lookup_key && == o. end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/payjpv2/models/price_create_request.rb', line 326 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
218 219 220 |
# File 'lib/payjpv2/models/price_create_request.rb', line 218 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
224 225 226 |
# File 'lib/payjpv2/models/price_create_request.rb', line 224 def hash [product_id, unit_amount, currency, id, active, nickname, lookup_key, ].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
302 303 304 |
# File 'lib/payjpv2/models/price_create_request.rb', line 302 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/payjpv2/models/price_create_request.rb', line 308 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
296 297 298 |
# File 'lib/payjpv2/models/price_create_request.rb', line 296 def to_s to_hash.to_s end |