Class: PAYJPv2::ProductDetailsResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/payjpv2/models/product_details_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProductDetailsResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/payjpv2/models/product_details_response.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::ProductDetailsResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::ProductDetailsResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:object)
    self.object = attributes[:object]
  else
    self.object = 'product'
  end

  if attributes.key?(:id)
    self.id = attributes[:id]
  else
    self.id = nil
  end

  if attributes.key?(:livemode)
    self.livemode = attributes[:livemode]
  else
    self.livemode = nil
  end

  if attributes.key?(:name)
    self.name = attributes[:name]
  else
    self.name = nil
  end

  if attributes.key?(:active)
    self.active = attributes[:active]
  else
    self.active = nil
  end

  if attributes.key?(:default_price_id)
    self.default_price_id = attributes[:default_price_id]
  else
    self.default_price_id = nil
  end

  if attributes.key?(:description)
    self.description = attributes[:description]
  else
    self.description = nil
  end

  if attributes.key?(:unit_label)
    self.unit_label = attributes[:unit_label]
  else
    self.unit_label = nil
  end

  if attributes.key?(:url)
    self.url = attributes[:url]
  else
    self.url = nil
  end

  if attributes.key?(:created_at)
    self.created_at = attributes[:created_at]
  else
    self.created_at = nil
  end

  if attributes.key?(:updated_at)
    self.updated_at = attributes[:updated_at]
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#activeObject

商品が購入可能かどうか



30
31
32
# File 'lib/payjpv2/models/product_details_response.rb', line 30

def active
  @active
end

#created_atObject

作成日時 (UTC, ISO 8601 形式)



41
42
43
# File 'lib/payjpv2/models/product_details_response.rb', line 41

def created_at
  @created_at
end

#default_price_idObject

Returns the value of attribute default_price_id.



32
33
34
# File 'lib/payjpv2/models/product_details_response.rb', line 32

def default_price_id
  @default_price_id
end

#descriptionObject

Returns the value of attribute description.



34
35
36
# File 'lib/payjpv2/models/product_details_response.rb', line 34

def description
  @description
end

#idObject

商品 ID



21
22
23
# File 'lib/payjpv2/models/product_details_response.rb', line 21

def id
  @id
end

#livemodeObject

本番環境かどうか



24
25
26
# File 'lib/payjpv2/models/product_details_response.rb', line 24

def livemode
  @livemode
end

#nameObject

Checkout などで顧客に表示される商品名



27
28
29
# File 'lib/payjpv2/models/product_details_response.rb', line 27

def name
  @name
end

#objectObject

Returns the value of attribute object.



18
19
20
# File 'lib/payjpv2/models/product_details_response.rb', line 18

def object
  @object
end

#unit_labelObject

Returns the value of attribute unit_label.



36
37
38
# File 'lib/payjpv2/models/product_details_response.rb', line 36

def unit_label
  @unit_label
end

#updated_atObject

更新日時 (UTC, ISO 8601 形式)



44
45
46
# File 'lib/payjpv2/models/product_details_response.rb', line 44

def updated_at
  @updated_at
end

#urlObject

Returns the value of attribute url.



38
39
40
# File 'lib/payjpv2/models/product_details_response.rb', line 38

def url
  @url
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/payjpv2/models/product_details_response.rb', line 332

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PAYJPv2.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/payjpv2/models/product_details_response.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/payjpv2/models/product_details_response.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/payjpv2/models/product_details_response.rb', line 69

def self.attribute_map
  {
    :object => :object,
    :id => :id,
    :livemode => :livemode,
    :name => :name,
    :active => :active,
    :default_price_id => :default_price_id,
    :description => :description,
    :unit_label => :unit_label,
    :url => :url,
    :created_at => :created_at,
    :updated_at => :updated_at
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/payjpv2/models/product_details_response.rb', line 308

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
117
118
119
120
# File 'lib/payjpv2/models/product_details_response.rb', line 113

def self.openapi_nullable
  Set.new([
    :default_price_id,
    :description,
    :unit_label,
    :url,
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/payjpv2/models/product_details_response.rb', line 96

def self.openapi_types
  {
    :object => :'String',
    :id => :'String',
    :livemode => :'Boolean',
    :name => :'String',
    :active => :'Boolean',
    :default_price_id => :'String',
    :description => :'String',
    :unit_label => :'String',
    :url => :'String',
    :created_at => :'Time',
    :updated_at => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/payjpv2/models/product_details_response.rb', line 277

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      object == o.object &&
      id == o.id &&
      livemode == o.livemode &&
      name == o.name &&
      active == o.active &&
      default_price_id == o.default_price_id &&
      description == o.description &&
      unit_label == o.unit_label &&
      url == o.url &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



403
404
405
406
407
408
409
410
411
412
413
414
415
# File 'lib/payjpv2/models/product_details_response.rb', line 403

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


295
296
297
# File 'lib/payjpv2/models/product_details_response.rb', line 295

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



301
302
303
# File 'lib/payjpv2/models/product_details_response.rb', line 301

def hash
  [object, id, livemode, name, active, default_price_id, description, unit_label, url, created_at, updated_at].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



379
380
381
# File 'lib/payjpv2/models/product_details_response.rb', line 379

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/payjpv2/models/product_details_response.rb', line 385

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



373
374
375
# File 'lib/payjpv2/models/product_details_response.rb', line 373

def to_s
  to_hash.to_s
end