Class: PAYJPv2::ProductUpdateRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/payjpv2/models/product_update_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProductUpdateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/payjpv2/models/product_update_request.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::ProductUpdateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::ProductUpdateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:name)
    self.name = attributes[:name]
  end

  if attributes.key?(:active)
    self.active = attributes[:active]
  end

  if attributes.key?(:default_price_id)
    self.default_price_id = attributes[:default_price_id]
  end

  if attributes.key?(:description)
    self.description = attributes[:description]
  end

  if attributes.key?(:unit_label)
    self.unit_label = attributes[:unit_label]
  end

  if attributes.key?(:url)
    self.url = attributes[:url]
  end
end

Instance Attribute Details

#activeObject

商品が購入可能かどうか



22
23
24
# File 'lib/payjpv2/models/product_update_request.rb', line 22

def active
  @active
end

#default_price_idObject

この商品のデフォルト価格である価格オブジェクトの ID



25
26
27
# File 'lib/payjpv2/models/product_update_request.rb', line 25

def default_price_id
  @default_price_id
end

#descriptionObject

Checkout などで顧客に表示される商品説明



28
29
30
# File 'lib/payjpv2/models/product_update_request.rb', line 28

def description
  @description
end

#nameObject

Checkout などで顧客に表示される商品名



19
20
21
# File 'lib/payjpv2/models/product_update_request.rb', line 19

def name
  @name
end

#unit_labelObject

この製品の単位を表すラベル。設定すると、Checkout などに表示されます。(例:「個」、「ライセンス」、「時間」、「回」など)



31
32
33
# File 'lib/payjpv2/models/product_update_request.rb', line 31

def unit_label
  @unit_label
end

#urlObject

この製品の公開されているウェブページの URL



34
35
36
# File 'lib/payjpv2/models/product_update_request.rb', line 34

def url
  @url
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/payjpv2/models/product_update_request.rb', line 169

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PAYJPv2.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/payjpv2/models/product_update_request.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/payjpv2/models/product_update_request.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/payjpv2/models/product_update_request.rb', line 37

def self.attribute_map
  {
    :name => :name,
    :active => :active,
    :default_price_id => :default_price_id,
    :description => :description,
    :unit_label => :unit_label,
    :url => :url
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/payjpv2/models/product_update_request.rb', line 145

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/payjpv2/models/product_update_request.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/payjpv2/models/product_update_request.rb', line 59

def self.openapi_types
  {
    :name => :'String',
    :active => :'Boolean',
    :default_price_id => :'String',
    :description => :'String',
    :unit_label => :'String',
    :url => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



119
120
121
122
123
124
125
126
127
128
# File 'lib/payjpv2/models/product_update_request.rb', line 119

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      active == o.active &&
      default_price_id == o.default_price_id &&
      description == o.description &&
      unit_label == o.unit_label &&
      url == o.url
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/payjpv2/models/product_update_request.rb', line 240

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


132
133
134
# File 'lib/payjpv2/models/product_update_request.rb', line 132

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



138
139
140
# File 'lib/payjpv2/models/product_update_request.rb', line 138

def hash
  [name, active, default_price_id, description, unit_label, url].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



216
217
218
# File 'lib/payjpv2/models/product_update_request.rb', line 216

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/payjpv2/models/product_update_request.rb', line 222

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



210
211
212
# File 'lib/payjpv2/models/product_update_request.rb', line 210

def to_s
  to_hash.to_s
end