Class: PAYJPv2::SetupFlowsApi
- Inherits:
-
Object
- Object
- PAYJPv2::SetupFlowsApi
- Defined in:
- lib/payjpv2/api/setup_flows_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cancel_setup_flow(setup_flow_id, opts = {}) ⇒ SetupFlowResponse, Array
Cancel Setup Flow.
-
#create_setup_flow(opts = {}) ⇒ SetupFlowResponse, Array
Create Setup Flow.
-
#get_all_setup_flows(opts = {}) ⇒ SetupFlowListResponse, Array
Get All Setup Flows.
-
#get_setup_flow(setup_flow_id, opts = {}) ⇒ SetupFlowResponse, Array
Get Setup Flow.
-
#initialize(api_client = ApiClient.default) ⇒ SetupFlowsApi
constructor
A new instance of SetupFlowsApi.
-
#update_setup_flow(setup_flow_id, setup_flow_update_request, opts = {}) ⇒ SetupFlowResponse, Array
Update Setup Flow.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SetupFlowsApi
Returns a new instance of SetupFlowsApi.
19 20 21 |
# File 'lib/payjpv2/api/setup_flows_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/payjpv2/api/setup_flows_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#cancel_setup_flow(setup_flow_id, opts = {}) ⇒ SetupFlowResponse, Array
Cancel Setup Flow
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/payjpv2/api/setup_flows_api.rb', line 29 def cancel_setup_flow(setup_flow_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SetupFlowsApi.cancel_setup_flow ...' end # verify the required parameter 'setup_flow_id' is set if @api_client.config.client_side_validation && setup_flow_id.nil? raise ArgumentError, "Missing the required parameter 'setup_flow_id' when calling SetupFlowsApi.cancel_setup_flow" end # resource path local_var_path = '/v2/setup_flows/{setup_flow_id}/cancel'.sub('{' + 'setup_flow_id' + '}', CGI.escape(setup_flow_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:setup_flow_cancel_request]) # return_type return_type = opts[:debug_return_type] || 'SetupFlowResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"SetupFlowsApi.cancel_setup_flow", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SetupFlowsApi#cancel_setup_flow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |
#create_setup_flow(opts = {}) ⇒ SetupFlowResponse, Array
Create Setup Flow
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/payjpv2/api/setup_flows_api.rb', line 94 def create_setup_flow(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SetupFlowsApi.create_setup_flow ...' end # resource path local_var_path = '/v2/setup_flows' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:setup_flow_create_request]) # return_type return_type = opts[:debug_return_type] || 'SetupFlowResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"SetupFlowsApi.create_setup_flow", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SetupFlowsApi#create_setup_flow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |
#get_all_setup_flows(opts = {}) ⇒ SetupFlowListResponse, Array
Get All Setup Flows
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/payjpv2/api/setup_flows_api.rb', line 157 def get_all_setup_flows(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SetupFlowsApi.get_all_setup_flows ...' end if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] > 100 raise ArgumentError, 'invalid value for "opts[:limit]" when calling SetupFlowsApi.get_all_setup_flows, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] < 1 raise ArgumentError, 'invalid value for "opts[:limit]" when calling SetupFlowsApi.get_all_setup_flows, must be greater than or equal to 1.' end # resource path local_var_path = '/v2/setup_flows' # query parameters query_params = opts[:query_params] || {} query_params[:limit] = opts[:limit] if !opts[:limit].nil? query_params[:starting_after] = opts[:starting_after] if !opts[:starting_after].nil? query_params[:ending_before] = opts[:ending_before] if !opts[:ending_before].nil? # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SetupFlowListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"SetupFlowsApi.get_all_setup_flows", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SetupFlowsApi#get_all_setup_flows\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |
#get_setup_flow(setup_flow_id, opts = {}) ⇒ SetupFlowResponse, Array
Get Setup Flow
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/payjpv2/api/setup_flows_api.rb', line 224 def get_setup_flow(setup_flow_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SetupFlowsApi.get_setup_flow ...' end # verify the required parameter 'setup_flow_id' is set if @api_client.config.client_side_validation && setup_flow_id.nil? raise ArgumentError, "Missing the required parameter 'setup_flow_id' when calling SetupFlowsApi.get_setup_flow" end # resource path local_var_path = '/v2/setup_flows/{setup_flow_id}'.sub('{' + 'setup_flow_id' + '}', CGI.escape(setup_flow_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SetupFlowResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"SetupFlowsApi.get_setup_flow", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SetupFlowsApi#get_setup_flow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |
#update_setup_flow(setup_flow_id, setup_flow_update_request, opts = {}) ⇒ SetupFlowResponse, Array
Update Setup Flow
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/payjpv2/api/setup_flows_api.rb', line 285 def update_setup_flow(setup_flow_id, setup_flow_update_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SetupFlowsApi.update_setup_flow ...' end # verify the required parameter 'setup_flow_id' is set if @api_client.config.client_side_validation && setup_flow_id.nil? raise ArgumentError, "Missing the required parameter 'setup_flow_id' when calling SetupFlowsApi.update_setup_flow" end # verify the required parameter 'setup_flow_update_request' is set if @api_client.config.client_side_validation && setup_flow_update_request.nil? raise ArgumentError, "Missing the required parameter 'setup_flow_update_request' when calling SetupFlowsApi.update_setup_flow" end # resource path local_var_path = '/v2/setup_flows/{setup_flow_id}'.sub('{' + 'setup_flow_id' + '}', CGI.escape(setup_flow_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(setup_flow_update_request) # return_type return_type = opts[:debug_return_type] || 'SetupFlowResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"SetupFlowsApi.update_setup_flow", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SetupFlowsApi#update_setup_flow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |