Class: PAYJPv2::StatementResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/payjpv2/models/statement_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ StatementResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/payjpv2/models/statement_response.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::StatementResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::StatementResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:object)
    self.object = attributes[:object]
  else
    self.object = 'statement'
  end

  if attributes.key?(:id)
    self.id = attributes[:id]
  else
    self.id = nil
  end

  if attributes.key?(:livemode)
    self.livemode = attributes[:livemode]
  else
    self.livemode = nil
  end

  if attributes.key?(:title)
    self.title = attributes[:title]
  else
    self.title = nil
  end

  if attributes.key?(:type)
    self.type = attributes[:type]
  else
    self.type = nil
  end

  if attributes.key?(:term)
    self.term = attributes[:term]
  else
    self.term = nil
  end

  if attributes.key?(:balance_id)
    self.balance_id = attributes[:balance_id]
  else
    self.balance_id = nil
  end

  if attributes.key?(:items)
    if (value = attributes[:items]).is_a?(Array)
      self.items = value
    end
  else
    self.items = nil
  end

  if attributes.key?(:net)
    self.net = attributes[:net]
  else
    self.net = nil
  end

  if attributes.key?(:created_at)
    self.created_at = attributes[:created_at]
  else
    self.created_at = nil
  end

  if attributes.key?(:updated_at)
    self.updated_at = attributes[:updated_at]
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#balance_idObject

Returns the value of attribute balance_id.



33
34
35
# File 'lib/payjpv2/models/statement_response.rb', line 33

def balance_id
  @balance_id
end

#created_atObject

作成日時 (UTC, ISO 8601 形式)



42
43
44
# File 'lib/payjpv2/models/statement_response.rb', line 42

def created_at
  @created_at
end

#idObject

明細 ID



21
22
23
# File 'lib/payjpv2/models/statement_response.rb', line 21

def id
  @id
end

#itemsObject

明細項目のリスト



36
37
38
# File 'lib/payjpv2/models/statement_response.rb', line 36

def items
  @items
end

#livemodeObject

本番環境かどうか



24
25
26
# File 'lib/payjpv2/models/statement_response.rb', line 24

def livemode
  @livemode
end

#netObject

含まれる statement_item の金額合計



39
40
41
# File 'lib/payjpv2/models/statement_response.rb', line 39

def net
  @net
end

#objectObject

Returns the value of attribute object.



18
19
20
# File 'lib/payjpv2/models/statement_response.rb', line 18

def object
  @object
end

#termObject

Returns the value of attribute term.



31
32
33
# File 'lib/payjpv2/models/statement_response.rb', line 31

def term
  @term
end

#titleObject

Returns the value of attribute title.



26
27
28
# File 'lib/payjpv2/models/statement_response.rb', line 26

def title
  @title
end

#typeObject

取引明細の区分 | 値 | 区分 | 詳細 | |—| — | — | | sales | 売上 | 決済による売上、決済手数料等 | | service_fee | サービス利用料 | 有料プランの月額費用など、sales に含まれないサービス利用料 | | forfeit | 残高失効 | - | | transfer_fee | 振込手数料 | - | | misc | その他 | 調整金など |



29
30
31
# File 'lib/payjpv2/models/statement_response.rb', line 29

def type
  @type
end

#updated_atObject

更新日時 (UTC, ISO 8601 形式)



45
46
47
# File 'lib/payjpv2/models/statement_response.rb', line 45

def updated_at
  @updated_at
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/payjpv2/models/statement_response.rb', line 344

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PAYJPv2.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



87
88
89
# File 'lib/payjpv2/models/statement_response.rb', line 87

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/payjpv2/models/statement_response.rb', line 92

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/payjpv2/models/statement_response.rb', line 70

def self.attribute_map
  {
    :object => :object,
    :id => :id,
    :livemode => :livemode,
    :title => :title,
    :type => :type,
    :term => :term,
    :balance_id => :balance_id,
    :items => :items,
    :net => :net,
    :created_at => :created_at,
    :updated_at => :updated_at
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/payjpv2/models/statement_response.rb', line 320

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
118
119
120
# File 'lib/payjpv2/models/statement_response.rb', line 114

def self.openapi_nullable
  Set.new([
    :title,
    :term,
    :balance_id,
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/payjpv2/models/statement_response.rb', line 97

def self.openapi_types
  {
    :object => :'String',
    :id => :'String',
    :livemode => :'Boolean',
    :title => :'String',
    :type => :'StatementType',
    :term => :'TermResponse',
    :balance_id => :'String',
    :items => :'Array<StatementItemResponse>',
    :net => :'Integer',
    :created_at => :'Time',
    :updated_at => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/payjpv2/models/statement_response.rb', line 289

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      object == o.object &&
      id == o.id &&
      livemode == o.livemode &&
      title == o.title &&
      type == o.type &&
      term == o.term &&
      balance_id == o.balance_id &&
      items == o.items &&
      net == o.net &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/payjpv2/models/statement_response.rb', line 415

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


307
308
309
# File 'lib/payjpv2/models/statement_response.rb', line 307

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



313
314
315
# File 'lib/payjpv2/models/statement_response.rb', line 313

def hash
  [object, id, livemode, title, type, term, balance_id, items, net, created_at, updated_at].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



391
392
393
# File 'lib/payjpv2/models/statement_response.rb', line 391

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/payjpv2/models/statement_response.rb', line 397

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



385
386
387
# File 'lib/payjpv2/models/statement_response.rb', line 385

def to_s
  to_hash.to_s
end