Class: PAYJPv2::StatementsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/payjpv2/api/statements_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ StatementsApi

Returns a new instance of StatementsApi.



19
20
21
# File 'lib/payjpv2/api/statements_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/payjpv2/api/statements_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_statement_url(statement_id, opts = {}) ⇒ StatementURLResponse, Array

Create Statement Url

Parameters:

  • statement_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (StatementURLResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/payjpv2/api/statements_api.rb', line 28

def create_statement_url(statement_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: StatementsApi.create_statement_url ...'
  end
  # verify the required parameter 'statement_id' is set
  if @api_client.config.client_side_validation && statement_id.nil?
    raise ArgumentError, "Missing the required parameter 'statement_id' when calling StatementsApi.create_statement_url"
  end
  # resource path
  local_var_path = '/v2/statements/{statement_id}/statement_urls'.sub('{' + 'statement_id' + '}', CGI.escape(statement_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'StatementURLResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"StatementsApi.create_statement_url",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: StatementsApi#create_statement_url\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end

#get_all_statements(opts = {}) ⇒ StatementListResponse, Array

Get All Statements

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :since (Time)

    指定した日付以降のデータを取得

  • :_until (Time)

    指定した日付以前のデータを取得

  • :limit (Integer)

    取得するデータの最大件数 (default to 10)

  • :starting_after (String)

    このIDより後のデータを取得

  • :ending_before (String)

    このIDより前のデータを取得

  • :type (StatementType)

    明細タイプでフィルタ

  • :term_id (String)

    集計区間 ID でフィルタ

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (StatementListResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/payjpv2/api/statements_api.rb', line 94

def get_all_statements(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: StatementsApi.get_all_statements ...'
  end
  if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] > 100
    raise ArgumentError, 'invalid value for "opts[:limit]" when calling StatementsApi.get_all_statements, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] < 1
    raise ArgumentError, 'invalid value for "opts[:limit]" when calling StatementsApi.get_all_statements, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/v2/statements'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:since] = opts[:since] if !opts[:since].nil?
  query_params[:until] = opts[:_until] if !opts[:_until].nil?
  query_params[:limit] = opts[:limit] if !opts[:limit].nil?
  query_params[:starting_after] = opts[:starting_after] if !opts[:starting_after].nil?
  query_params[:ending_before] = opts[:ending_before] if !opts[:ending_before].nil?
  query_params[:type] = opts[:type] if !opts[:type].nil?
  query_params[:term_id] = opts[:term_id] if !opts[:term_id].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'StatementListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"StatementsApi.get_all_statements",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: StatementsApi#get_all_statements\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end

#get_statement(statement_id, opts = {}) ⇒ StatementResponse, Array

Get Statement

Parameters:

  • statement_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (StatementResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/payjpv2/api/statements_api.rb', line 165

def get_statement(statement_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: StatementsApi.get_statement ...'
  end
  # verify the required parameter 'statement_id' is set
  if @api_client.config.client_side_validation && statement_id.nil?
    raise ArgumentError, "Missing the required parameter 'statement_id' when calling StatementsApi.get_statement"
  end
  # resource path
  local_var_path = '/v2/statements/{statement_id}'.sub('{' + 'statement_id' + '}', CGI.escape(statement_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'StatementResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"StatementsApi.get_statement",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: StatementsApi#get_statement\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end