Class: PAYJPv2::TaxRatesApi
- Inherits:
-
Object
- Object
- PAYJPv2::TaxRatesApi
- Defined in:
- lib/payjpv2/api/tax_rates_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_tax_rate(tax_rate_create_request, opts = {}) ⇒ TaxRateDetailsResponse, Array
Create Tax Rate.
-
#get_all_tax_rates(opts = {}) ⇒ TaxRateListResponse, Array
Get All Tax Rates.
-
#get_tax_rate(tax_rate_id, opts = {}) ⇒ TaxRateDetailsResponse, Array
Get Tax Rate.
-
#initialize(api_client = ApiClient.default) ⇒ TaxRatesApi
constructor
A new instance of TaxRatesApi.
-
#update_tax_rate(tax_rate_id, tax_rate_update_request, opts = {}) ⇒ TaxRateDetailsResponse, Array
Update Tax Rate.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TaxRatesApi
Returns a new instance of TaxRatesApi.
19 20 21 |
# File 'lib/payjpv2/api/tax_rates_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/payjpv2/api/tax_rates_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_tax_rate(tax_rate_create_request, opts = {}) ⇒ TaxRateDetailsResponse, Array
Create Tax Rate
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/payjpv2/api/tax_rates_api.rb', line 28 def create_tax_rate(tax_rate_create_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TaxRatesApi.create_tax_rate ...' end # verify the required parameter 'tax_rate_create_request' is set if @api_client.config.client_side_validation && tax_rate_create_request.nil? raise ArgumentError, "Missing the required parameter 'tax_rate_create_request' when calling TaxRatesApi.create_tax_rate" end # resource path local_var_path = '/v2/tax_rates' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(tax_rate_create_request) # return_type return_type = opts[:debug_return_type] || 'TaxRateDetailsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"TaxRatesApi.create_tax_rate", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TaxRatesApi#create_tax_rate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |
#get_all_tax_rates(opts = {}) ⇒ TaxRateListResponse, Array
Get All Tax Rates
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/payjpv2/api/tax_rates_api.rb', line 97 def get_all_tax_rates(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TaxRatesApi.get_all_tax_rates ...' end if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] > 100 raise ArgumentError, 'invalid value for "opts[:limit]" when calling TaxRatesApi.get_all_tax_rates, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] < 1 raise ArgumentError, 'invalid value for "opts[:limit]" when calling TaxRatesApi.get_all_tax_rates, must be greater than or equal to 1.' end # resource path local_var_path = '/v2/tax_rates' # query parameters query_params = opts[:query_params] || {} query_params[:limit] = opts[:limit] if !opts[:limit].nil? query_params[:starting_after] = opts[:starting_after] if !opts[:starting_after].nil? query_params[:ending_before] = opts[:ending_before] if !opts[:ending_before].nil? query_params[:active] = opts[:active] if !opts[:active].nil? query_params[:inclusive] = opts[:inclusive] if !opts[:inclusive].nil? # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TaxRateListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"TaxRatesApi.get_all_tax_rates", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TaxRatesApi#get_all_tax_rates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |
#get_tax_rate(tax_rate_id, opts = {}) ⇒ TaxRateDetailsResponse, Array
Get Tax Rate
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/payjpv2/api/tax_rates_api.rb', line 166 def get_tax_rate(tax_rate_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TaxRatesApi.get_tax_rate ...' end # verify the required parameter 'tax_rate_id' is set if @api_client.config.client_side_validation && tax_rate_id.nil? raise ArgumentError, "Missing the required parameter 'tax_rate_id' when calling TaxRatesApi.get_tax_rate" end # resource path local_var_path = '/v2/tax_rates/{tax_rate_id}'.sub('{' + 'tax_rate_id' + '}', CGI.escape(tax_rate_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TaxRateDetailsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"TaxRatesApi.get_tax_rate", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TaxRatesApi#get_tax_rate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |
#update_tax_rate(tax_rate_id, tax_rate_update_request, opts = {}) ⇒ TaxRateDetailsResponse, Array
Update Tax Rate
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/payjpv2/api/tax_rates_api.rb', line 227 def update_tax_rate(tax_rate_id, tax_rate_update_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TaxRatesApi.update_tax_rate ...' end # verify the required parameter 'tax_rate_id' is set if @api_client.config.client_side_validation && tax_rate_id.nil? raise ArgumentError, "Missing the required parameter 'tax_rate_id' when calling TaxRatesApi.update_tax_rate" end # verify the required parameter 'tax_rate_update_request' is set if @api_client.config.client_side_validation && tax_rate_update_request.nil? raise ArgumentError, "Missing the required parameter 'tax_rate_update_request' when calling TaxRatesApi.update_tax_rate" end # resource path local_var_path = '/v2/tax_rates/{tax_rate_id}'.sub('{' + 'tax_rate_id' + '}', CGI.escape(tax_rate_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(tax_rate_update_request) # return_type return_type = opts[:debug_return_type] || 'TaxRateDetailsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"TaxRatesApi.update_tax_rate", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TaxRatesApi#update_tax_rate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |