Class: PAYJPv2::TermResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/payjpv2/models/term_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TermResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/payjpv2/models/term_response.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::TermResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::TermResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:object)
    self.object = attributes[:object]
  else
    self.object = 'term'
  end

  if attributes.key?(:id)
    self.id = attributes[:id]
  else
    self.id = nil
  end

  if attributes.key?(:livemode)
    self.livemode = attributes[:livemode]
  else
    self.livemode = nil
  end

  if attributes.key?(:start_at)
    self.start_at = attributes[:start_at]
  else
    self.start_at = nil
  end

  if attributes.key?(:end_at)
    self.end_at = attributes[:end_at]
  else
    self.end_at = nil
  end

  if attributes.key?(:closed)
    self.closed = attributes[:closed]
  else
    self.closed = nil
  end
end

Instance Attribute Details

#closedObject

締め処理が完了済みなら true



33
34
35
# File 'lib/payjpv2/models/term_response.rb', line 33

def closed
  @closed
end

#end_atObject

区間終了時刻 Term が表す区間は start_at 以上 end_at 未満の範囲となります。 翌サイクルの Term の場合 null を返します。



30
31
32
# File 'lib/payjpv2/models/term_response.rb', line 30

def end_at
  @end_at
end

#idObject

集計区間 ID



21
22
23
# File 'lib/payjpv2/models/term_response.rb', line 21

def id
  @id
end

#livemodeObject

本番環境かどうか



24
25
26
# File 'lib/payjpv2/models/term_response.rb', line 24

def livemode
  @livemode
end

#objectObject

Returns the value of attribute object.



18
19
20
# File 'lib/payjpv2/models/term_response.rb', line 18

def object
  @object
end

#start_atObject

区間開始時刻



27
28
29
# File 'lib/payjpv2/models/term_response.rb', line 27

def start_at
  @start_at
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/payjpv2/models/term_response.rb', line 262

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PAYJPv2.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/payjpv2/models/term_response.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/payjpv2/models/term_response.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/payjpv2/models/term_response.rb', line 58

def self.attribute_map
  {
    :object => :object,
    :id => :id,
    :livemode => :livemode,
    :start_at => :start_at,
    :end_at => :end_at,
    :closed => :closed
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/payjpv2/models/term_response.rb', line 238

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/payjpv2/models/term_response.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/payjpv2/models/term_response.rb', line 80

def self.openapi_types
  {
    :object => :'String',
    :id => :'String',
    :livemode => :'Boolean',
    :start_at => :'Time',
    :end_at => :'Time',
    :closed => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



212
213
214
215
216
217
218
219
220
221
# File 'lib/payjpv2/models/term_response.rb', line 212

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      object == o.object &&
      id == o.id &&
      livemode == o.livemode &&
      start_at == o.start_at &&
      end_at == o.end_at &&
      closed == o.closed
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/payjpv2/models/term_response.rb', line 333

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/payjpv2/models/term_response.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/payjpv2/models/term_response.rb', line 231

def hash
  [object, id, livemode, start_at, end_at, closed].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



309
310
311
# File 'lib/payjpv2/models/term_response.rb', line 309

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/payjpv2/models/term_response.rb', line 315

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



303
304
305
# File 'lib/payjpv2/models/term_response.rb', line 303

def to_s
  to_hash.to_s
end