Class: PAYJPv2::TermsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/payjpv2/api/terms_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ TermsApi

Returns a new instance of TermsApi.



19
20
21
# File 'lib/payjpv2/api/terms_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/payjpv2/api/terms_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_all_terms(opts = {}) ⇒ TermListResponse, Array

Get All Terms

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    取得するデータの最大件数 (default to 10)

  • :starting_after (String)

    このIDより後のデータを取得

  • :ending_before (String)

    このIDより前のデータを取得

  • :since_start_at (Time)

    start_at が指定した日付以降のデータを取得

  • :until_start_at (Time)

    start_at が指定した日付以前のデータを取得

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (TermListResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/payjpv2/api/terms_api.rb', line 32

def get_all_terms(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TermsApi.get_all_terms ...'
  end
  if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] > 100
    raise ArgumentError, 'invalid value for "opts[:limit]" when calling TermsApi.get_all_terms, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] < 1
    raise ArgumentError, 'invalid value for "opts[:limit]" when calling TermsApi.get_all_terms, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/v2/terms'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:limit] = opts[:limit] if !opts[:limit].nil?
  query_params[:starting_after] = opts[:starting_after] if !opts[:starting_after].nil?
  query_params[:ending_before] = opts[:ending_before] if !opts[:ending_before].nil?
  query_params[:since_start_at] = opts[:since_start_at] if !opts[:since_start_at].nil?
  query_params[:until_start_at] = opts[:until_start_at] if !opts[:until_start_at].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'TermListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"TermsApi.get_all_terms",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TermsApi#get_all_terms\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end

#get_term(term_id, opts = {}) ⇒ TermResponse, Array

Get Term

Parameters:

  • term_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    Idempotency key for the request

  • :include_http_info (Boolean)

    If true, returns [data, status_code, headers] instead of just data

Returns:

  • (TermResponse, Array)

    Returns data or [data, status_code, headers] if include_http_info is true



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/payjpv2/api/terms_api.rb', line 101

def get_term(term_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TermsApi.get_term ...'
  end
  # verify the required parameter 'term_id' is set
  if @api_client.config.client_side_validation && term_id.nil?
    raise ArgumentError, "Missing the required parameter 'term_id' when calling TermsApi.get_term"
  end
  # resource path
  local_var_path = '/v2/terms/{term_id}'.sub('{' + 'term_id' + '}', CGI.escape(term_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key]
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'TermResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer']

  new_options = opts.merge(
    :operation => :"TermsApi.get_term",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TermsApi#get_term\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end

  if opts[:include_http_info]
    [data, status_code, headers]
  else
    data
  end
end