Class: PAYJPv2::CheckoutSessionsApi
- Inherits:
-
Object
- Object
- PAYJPv2::CheckoutSessionsApi
- Defined in:
- lib/payjpv2/api/checkout_sessions_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_checkout_session(checkout_session_create_request, opts = {}) ⇒ CheckoutSessionDetailsResponse, Array
Create Checkout Session.
-
#get_all_checkout_session_line_items(checkout_session_id, opts = {}) ⇒ CheckoutSessionLineItemListResponse, Array
Get All Checkout Session Line Items.
-
#get_all_checkout_sessions(opts = {}) ⇒ CheckoutSessionListResponse, Array
Get All Checkout Sessions.
-
#get_checkout_session(checkout_session_id, opts = {}) ⇒ CheckoutSessionDetailsResponse, Array
Get Checkout Session.
-
#initialize(api_client = ApiClient.default) ⇒ CheckoutSessionsApi
constructor
A new instance of CheckoutSessionsApi.
-
#update_checkout_session(checkout_session_id, checkout_session_update_request, opts = {}) ⇒ CheckoutSessionDetailsResponse, Array
Update Checkout Session.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CheckoutSessionsApi
Returns a new instance of CheckoutSessionsApi.
19 20 21 |
# File 'lib/payjpv2/api/checkout_sessions_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/payjpv2/api/checkout_sessions_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_checkout_session(checkout_session_create_request, opts = {}) ⇒ CheckoutSessionDetailsResponse, Array
Create Checkout Session
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/payjpv2/api/checkout_sessions_api.rb', line 28 def create_checkout_session(checkout_session_create_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CheckoutSessionsApi.create_checkout_session ...' end # verify the required parameter 'checkout_session_create_request' is set if @api_client.config.client_side_validation && checkout_session_create_request.nil? raise ArgumentError, "Missing the required parameter 'checkout_session_create_request' when calling CheckoutSessionsApi.create_checkout_session" end # resource path local_var_path = '/v2/checkout/sessions' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(checkout_session_create_request) # return_type return_type = opts[:debug_return_type] || 'CheckoutSessionDetailsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"CheckoutSessionsApi.create_checkout_session", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CheckoutSessionsApi#create_checkout_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |
#get_all_checkout_session_line_items(checkout_session_id, opts = {}) ⇒ CheckoutSessionLineItemListResponse, Array
Get All Checkout Session Line Items
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/payjpv2/api/checkout_sessions_api.rb', line 96 def get_all_checkout_session_line_items(checkout_session_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CheckoutSessionsApi.get_all_checkout_session_line_items ...' end # verify the required parameter 'checkout_session_id' is set if @api_client.config.client_side_validation && checkout_session_id.nil? raise ArgumentError, "Missing the required parameter 'checkout_session_id' when calling CheckoutSessionsApi.get_all_checkout_session_line_items" end if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] > 100 raise ArgumentError, 'invalid value for "opts[:limit]" when calling CheckoutSessionsApi.get_all_checkout_session_line_items, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] < 1 raise ArgumentError, 'invalid value for "opts[:limit]" when calling CheckoutSessionsApi.get_all_checkout_session_line_items, must be greater than or equal to 1.' end # resource path local_var_path = '/v2/checkout/sessions/{checkout_session_id}/line_items'.sub('{' + 'checkout_session_id' + '}', CGI.escape(checkout_session_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:limit] = opts[:limit] if !opts[:limit].nil? query_params[:starting_after] = opts[:starting_after] if !opts[:starting_after].nil? query_params[:ending_before] = opts[:ending_before] if !opts[:ending_before].nil? # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CheckoutSessionLineItemListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"CheckoutSessionsApi.get_all_checkout_session_line_items", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CheckoutSessionsApi#get_all_checkout_session_line_items\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |
#get_all_checkout_sessions(opts = {}) ⇒ CheckoutSessionListResponse, Array
Get All Checkout Sessions
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/payjpv2/api/checkout_sessions_api.rb', line 169 def get_all_checkout_sessions(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CheckoutSessionsApi.get_all_checkout_sessions ...' end if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] > 100 raise ArgumentError, 'invalid value for "opts[:limit]" when calling CheckoutSessionsApi.get_all_checkout_sessions, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:limit].nil? && opts[:limit] < 1 raise ArgumentError, 'invalid value for "opts[:limit]" when calling CheckoutSessionsApi.get_all_checkout_sessions, must be greater than or equal to 1.' end # resource path local_var_path = '/v2/checkout/sessions' # query parameters query_params = opts[:query_params] || {} query_params[:limit] = opts[:limit] if !opts[:limit].nil? query_params[:starting_after] = opts[:starting_after] if !opts[:starting_after].nil? query_params[:ending_before] = opts[:ending_before] if !opts[:ending_before].nil? # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CheckoutSessionListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"CheckoutSessionsApi.get_all_checkout_sessions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CheckoutSessionsApi#get_all_checkout_sessions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |
#get_checkout_session(checkout_session_id, opts = {}) ⇒ CheckoutSessionDetailsResponse, Array
Get Checkout Session
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/payjpv2/api/checkout_sessions_api.rb', line 236 def get_checkout_session(checkout_session_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CheckoutSessionsApi.get_checkout_session ...' end # verify the required parameter 'checkout_session_id' is set if @api_client.config.client_side_validation && checkout_session_id.nil? raise ArgumentError, "Missing the required parameter 'checkout_session_id' when calling CheckoutSessionsApi.get_checkout_session" end # resource path local_var_path = '/v2/checkout/sessions/{checkout_session_id}'.sub('{' + 'checkout_session_id' + '}', CGI.escape(checkout_session_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CheckoutSessionDetailsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"CheckoutSessionsApi.get_checkout_session", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CheckoutSessionsApi#get_checkout_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |
#update_checkout_session(checkout_session_id, checkout_session_update_request, opts = {}) ⇒ CheckoutSessionDetailsResponse, Array
Update Checkout Session
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/payjpv2/api/checkout_sessions_api.rb', line 297 def update_checkout_session(checkout_session_id, checkout_session_update_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CheckoutSessionsApi.update_checkout_session ...' end # verify the required parameter 'checkout_session_id' is set if @api_client.config.client_side_validation && checkout_session_id.nil? raise ArgumentError, "Missing the required parameter 'checkout_session_id' when calling CheckoutSessionsApi.update_checkout_session" end # verify the required parameter 'checkout_session_update_request' is set if @api_client.config.client_side_validation && checkout_session_update_request.nil? raise ArgumentError, "Missing the required parameter 'checkout_session_update_request' when calling CheckoutSessionsApi.update_checkout_session" end # resource path local_var_path = '/v2/checkout/sessions/{checkout_session_id}'.sub('{' + 'checkout_session_id' + '}', CGI.escape(checkout_session_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params['Idempotency-Key'] = opts[:idempotency_key] if opts[:idempotency_key] # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(checkout_session_update_request) # return_type return_type = opts[:debug_return_type] || 'CheckoutSessionDetailsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBasic', 'HTTPBearer'] = opts.merge( :operation => :"CheckoutSessionsApi.update_checkout_session", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CheckoutSessionsApi#update_checkout_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end if opts[:include_http_info] [data, status_code, headers] else data end end |