Class: PAYJPv2::CustomerCreateRequest
- Inherits:
-
Object
- Object
- PAYJPv2::CustomerCreateRequest
- Defined in:
- lib/payjpv2/models/customer_create_request.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
顧客オブジェクトに付加できる任意の文字列です。管理画面で顧客と一緒に表示されます。.
-
#email ⇒ Object
顧客のメールアドレス。メールアドレスの形式が正しいかどうかは検証されます。.
-
#id ⇒ Object
顧客 ID。100桁までの一意な文字列を指定できます。使える文字は半角英数字、ハイフン(-)、アンダースコア(_)です。未指定時は ‘cus_` で始まる一意な文字列が自動生成されます。.
-
#metadata ⇒ Object
キーバリューの任意のデータを格納できます。20件まで登録可能で、空文字列を指定するとそのキーを削除できます。<a href="docs.pay.jp/v2/guide/developers/metadata">詳細はメタデータのドキュメントを参照してください。</a>.
-
#payment_method_id ⇒ Object
顧客に紐づける支払い方法 ID。同時にデフォルトの支払い方法として登録されます。.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomerCreateRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CustomerCreateRequest
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::CustomerCreateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::CustomerCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:id) self.id = attributes[:id] end if attributes.key?(:payment_method_id) self.payment_method_id = attributes[:payment_method_id] end if attributes.key?(:email) self.email = attributes[:email] end if attributes.key?(:description) self.description = attributes[:description] end if attributes.key?(:metadata) if (value = attributes[:metadata]).is_a?(Hash) self. = value end end end |
Instance Attribute Details
#description ⇒ Object
顧客オブジェクトに付加できる任意の文字列です。管理画面で顧客と一緒に表示されます。
28 29 30 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 28 def description @description end |
#email ⇒ Object
顧客のメールアドレス。メールアドレスの形式が正しいかどうかは検証されます。
25 26 27 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 25 def email @email end |
#id ⇒ Object
顧客 ID。100桁までの一意な文字列を指定できます。使える文字は半角英数字、ハイフン(-)、アンダースコア(_)です。未指定時は ‘cus_` で始まる一意な文字列が自動生成されます。
19 20 21 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 19 def id @id end |
#metadata ⇒ Object
キーバリューの任意のデータを格納できます。20件まで登録可能で、空文字列を指定するとそのキーを削除できます。<a href="docs.pay.jp/v2/guide/developers/metadata">詳細はメタデータのドキュメントを参照してください。</a>
31 32 33 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 31 def @metadata end |
#payment_method_id ⇒ Object
顧客に紐づける支払い方法 ID。同時にデフォルトの支払い方法として登録されます。
22 23 24 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 22 def payment_method_id @payment_method_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 208 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PAYJPv2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 34 def self.attribute_map { :id => :id, :payment_method_id => :payment_method_id, :email => :email, :description => :description, :metadata => :metadata } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 184 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 55 def self.openapi_types { :id => :'String', :payment_method_id => :'String', :email => :'String', :description => :'String', :metadata => :'Hash<String, MetadataValue>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
159 160 161 162 163 164 165 166 167 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 159 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && payment_method_id == o.payment_method_id && email == o.email && description == o.description && == o. end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 279 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
171 172 173 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 171 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 177 def hash [id, payment_method_id, email, description, ].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
255 256 257 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 255 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 261 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
249 250 251 |
# File 'lib/payjpv2/models/customer_create_request.rb', line 249 def to_s to_hash.to_s end |