Class: PAYJPv2::PaymentFlowCreateRequest
- Inherits:
-
Object
- Object
- PAYJPv2::PaymentFlowCreateRequest
- Defined in:
- lib/payjpv2/models/payment_flow_create_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
支払い予定の金額。50円以上9,999,999円以下である必要があります。.
-
#capture_method ⇒ Object
支払いの確定方法を指定します。 | 値 | |:—| | automatic: (デフォルト) 顧客が支払いを承認すると、自動的に確定させます。 | | manual: 顧客が支払いを承認すると一旦確定を保留し、後で Payment Flow の Capture API を使用して確定します。(すべての支払い方法がこれをサポートしているわけではありません)。 |.
-
#confirm ⇒ Object
「true」に設定すると、この PaymentFlow を直ちに確定しようと試みます。.
-
#currency ⇒ Object
価格の通貨。現在は ‘jpy` のみサポートしています。.
-
#customer_id ⇒ Object
この PaymentFlow に関連付ける顧客の ID.
-
#description ⇒ Object
オブジェクトにセットする任意の文字列。.
-
#metadata ⇒ Object
キーバリューの任意のデータを格納できます。20件まで登録可能で、空文字列を指定するとそのキーを削除できます。<a href="docs.pay.jp/v2/guide/developers/metadata">詳細はメタデータのドキュメントを参照してください。</a>.
-
#payment_method_id ⇒ Object
支払い方法 ID。customer_id の指定が必須です。Customer が所持する PaymentMethod のみ指定できます。payment_method_id を指定せず、Customer に default_payment_method_id が設定されている場合はそちらが自動でセットされます。.
-
#payment_method_options ⇒ Object
この PaymentFlow 固有の支払い方法の設定.
-
#payment_method_types ⇒ Object
この PaymentFlow で使用できる支払い方法の種類のリスト。指定しない場合は、PAY.JP は支払い方法の設定から利用可能な支払い方法を動的に表示します。.
-
#return_url ⇒ Object
顧客が支払いを完了後かキャンセルした後にリダイレクトされる URL。アプリにリダイレクトしたい場合は URI Scheme を指定できます。confirm=true の場合のみ指定できます。.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentFlowCreateRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PaymentFlowCreateRequest
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 125 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::PaymentFlowCreateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::PaymentFlowCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:amount) self.amount = attributes[:amount] else self.amount = nil end if attributes.key?(:customer_id) self.customer_id = attributes[:customer_id] end if attributes.key?(:payment_method_id) self.payment_method_id = attributes[:payment_method_id] end if attributes.key?(:payment_method_options) self. = attributes[:payment_method_options] end if attributes.key?(:payment_method_types) if (value = attributes[:payment_method_types]).is_a?(Array) self.payment_method_types = value end end if attributes.key?(:currency) self.currency = attributes[:currency] else self.currency = nil end if attributes.key?(:capture_method) self.capture_method = attributes[:capture_method] end if attributes.key?(:confirm) self.confirm = attributes[:confirm] else self.confirm = false end if attributes.key?(:return_url) self.return_url = attributes[:return_url] end if attributes.key?(:description) self.description = attributes[:description] end if attributes.key?(:metadata) if (value = attributes[:metadata]).is_a?(Hash) self. = value end end end |
Instance Attribute Details
#amount ⇒ Object
支払い予定の金額。50円以上9,999,999円以下である必要があります。
19 20 21 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 19 def amount @amount end |
#capture_method ⇒ Object
支払いの確定方法を指定します。 | 値 | |:—| | automatic: (デフォルト) 顧客が支払いを承認すると、自動的に確定させます。 | | manual: 顧客が支払いを承認すると一旦確定を保留し、後で Payment Flow の Capture API を使用して確定します。(すべての支払い方法がこれをサポートしているわけではありません)。 |
37 38 39 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 37 def capture_method @capture_method end |
#confirm ⇒ Object
「true」に設定すると、この PaymentFlow を直ちに確定しようと試みます。
40 41 42 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 40 def confirm @confirm end |
#currency ⇒ Object
価格の通貨。現在は ‘jpy` のみサポートしています。
34 35 36 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 34 def currency @currency end |
#customer_id ⇒ Object
この PaymentFlow に関連付ける顧客の ID
22 23 24 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 22 def customer_id @customer_id end |
#description ⇒ Object
オブジェクトにセットする任意の文字列。
46 47 48 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 46 def description @description end |
#metadata ⇒ Object
キーバリューの任意のデータを格納できます。20件まで登録可能で、空文字列を指定するとそのキーを削除できます。<a href="docs.pay.jp/v2/guide/developers/metadata">詳細はメタデータのドキュメントを参照してください。</a>
49 50 51 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 49 def @metadata end |
#payment_method_id ⇒ Object
支払い方法 ID。customer_id の指定が必須です。Customer が所持する PaymentMethod のみ指定できます。payment_method_id を指定せず、Customer に default_payment_method_id が設定されている場合はそちらが自動でセットされます。
25 26 27 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 25 def payment_method_id @payment_method_id end |
#payment_method_options ⇒ Object
この PaymentFlow 固有の支払い方法の設定
28 29 30 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 28 def @payment_method_options end |
#payment_method_types ⇒ Object
この PaymentFlow で使用できる支払い方法の種類のリスト。指定しない場合は、PAY.JP は支払い方法の設定から利用可能な支払い方法を動的に表示します。
31 32 33 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 31 def payment_method_types @payment_method_types end |
#return_url ⇒ Object
顧客が支払いを完了後かキャンセルした後にリダイレクトされる URL。アプリにリダイレクトしたい場合は URI Scheme を指定できます。confirm=true の場合のみ指定できます。
43 44 45 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 43 def return_url @return_url end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 279 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PAYJPv2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
91 92 93 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 91 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 96 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 74 def self.attribute_map { :amount => :amount, :customer_id => :customer_id, :payment_method_id => :payment_method_id, :payment_method_options => :payment_method_options, :payment_method_types => :payment_method_types, :currency => :currency, :capture_method => :capture_method, :confirm => :confirm, :return_url => :return_url, :description => :description, :metadata => :metadata } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 255 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 118 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 101 def self.openapi_types { :amount => :'Integer', :customer_id => :'String', :payment_method_id => :'String', :payment_method_options => :'PaymentFlowPaymentMethodOptionsRequest', :payment_method_types => :'Array<PaymentMethodTypes>', :currency => :'Currency', :capture_method => :'CaptureMethod', :confirm => :'Boolean', :return_url => :'String', :description => :'String', :metadata => :'Hash<String, MetadataValue>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 224 def ==(o) return true if self.equal?(o) self.class == o.class && amount == o.amount && customer_id == o.customer_id && payment_method_id == o.payment_method_id && == o. && payment_method_types == o.payment_method_types && currency == o.currency && capture_method == o.capture_method && confirm == o.confirm && return_url == o.return_url && description == o.description && == o. end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 350 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
242 243 244 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 242 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 248 def hash [amount, customer_id, payment_method_id, , payment_method_types, currency, capture_method, confirm, return_url, description, ].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
326 327 328 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 326 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 332 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
320 321 322 |
# File 'lib/payjpv2/models/payment_flow_create_request.rb', line 320 def to_s to_hash.to_s end |