Class: PAYJPv2::TaxRateUpdateRequest
- Inherits:
-
Object
- Object
- PAYJPv2::TaxRateUpdateRequest
- Defined in:
- lib/payjpv2/models/tax_rate_update_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active ⇒ Object
この税率が有効であるかどうか。無効にした場合でも、すでに設定されている定期課金などでは使用可能です。.
-
#country ⇒ Object
有効な2文字の <a href="ja.wikipedia.org/wiki/ISO_3166-1" target="_blank">ISO 国コード</a>.
-
#description ⇒ Object
説明。管理画面内のみで表示され、顧客には表示されません。.
-
#display_name ⇒ Object
表示名。顧客に表示されます。.
-
#metadata ⇒ Object
キーバリューの任意のデータを格納できます。20件まで登録可能で、空文字列を指定するとそのキーを削除できます。<a href="docs.pay.jp/v2/guide/developers/metadata">詳細はメタデータのドキュメントを参照してください。</a>.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TaxRateUpdateRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TaxRateUpdateRequest
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise ArgumentError, "The input argument (attributes) must be a hash in `PAYJPv2::TaxRateUpdateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) raise ArgumentError, "`#{k}` is not a valid attribute in `PAYJPv2::TaxRateUpdateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:active) self.active = attributes[:active] end if attributes.key?(:country) self.country = attributes[:country] end if attributes.key?(:description) self.description = attributes[:description] end if attributes.key?(:display_name) self.display_name = attributes[:display_name] end if attributes.key?(:metadata) if (value = attributes[:metadata]).is_a?(Hash) self. = value end end end |
Instance Attribute Details
#active ⇒ Object
この税率が有効であるかどうか。無効にした場合でも、すでに設定されている定期課金などでは使用可能です。
19 20 21 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 19 def active @active end |
#country ⇒ Object
有効な2文字の <a href="ja.wikipedia.org/wiki/ISO_3166-1" target="_blank">ISO 国コード</a>
22 23 24 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 22 def country @country end |
#description ⇒ Object
説明。管理画面内のみで表示され、顧客には表示されません。
25 26 27 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 25 def description @description end |
#display_name ⇒ Object
表示名。顧客に表示されます。
28 29 30 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 28 def display_name @display_name end |
#metadata ⇒ Object
キーバリューの任意のデータを格納できます。20件まで登録可能で、空文字列を指定するとそのキーを削除できます。<a href="docs.pay.jp/v2/guide/developers/metadata">詳細はメタデータのドキュメントを参照してください。</a>
31 32 33 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 31 def @metadata end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 183 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PAYJPv2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 56 def self.attribute_map { :active => :active, :country => :country, :description => :description, :display_name => :display_name, :metadata => :metadata } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 159 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 77 def self.openapi_types { :active => :'Boolean', :country => :'Country', :description => :'String', :display_name => :'String', :metadata => :'Hash<String, MetadataValue>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 134 def ==(o) return true if self.equal?(o) self.class == o.class && active == o.active && country == o.country && description == o.description && display_name == o.display_name && == o. end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 254 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
146 147 148 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 146 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
152 153 154 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 152 def hash [active, country, description, display_name, ].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
230 231 232 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 230 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
224 225 226 |
# File 'lib/payjpv2/models/tax_rate_update_request.rb', line 224 def to_s to_hash.to_s end |